"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501

class AllowedPermissionEnum(object):
    """Implementation of the 'AllowedPermission' enum.

    Attributes:
        MANAGECLASSANDEVENTDESCRIPTIONS: The enum member of type str.
        MANAGECLASSSCHEDULES: The enum member of type str.
        SCHEDULEFREECLASSESANDEVENTS: The enum member of type str.
        SCHEDULERESOURCESFORCLASSESANDEVENTS: The enum member of type str.
        SUBSTITUTECLASSANDEVENTTEACHERS: The enum member of type str.
        BULKEDITCLASSSCHEDULES: The enum member of type str.
        ADDSTAFFMEMBERS: The enum member of type str.
        MANAGEPERSONALINFOFORSTAFF: The enum member of type str.
        MANAGESTAFFSETTINGS: The enum member of type str.
        MANAGESTAFFLOGINS: The enum member of type str.
        MANAGESTAFFSCHEDULES: The enum member of type str.
        MANAGESTAFFPAYRATES: The enum member of type str.
        ACCESSBUSINESSINFORMATIONSCREEN: The enum member of type str.
        ACCESSGENERALSETUPOPTIONSSCREEN: The enum member of type str.
        ACCESSNEWSEVENTSSCREEN: The enum member of type str.
        MANAGEHOLIDAYS: The enum member of type str.
        CLASSANDEVENTOPTIONSSCREEN: The enum member of type str.
        APPOINTMENTOPTIONSSCREEN: The enum member of type str.
        ACCESSMEDIAMANAGEMENTSCREEN: The enum member of type str.
        ACCESSMEMBERSHIPSETUPSCREEN: The enum member of type str.
        MANAGEPAYMENTMETHODS: The enum member of type str.
        MANAGEROOMNUMBERS: The enum member of type str.
        ACCESSRESOURCEMANAGEMENTSCREEN: The enum member of type str.
        ACCESSRESOURCESSCHEDULINGTAB: The enum member of type str.
        ACCESSLINKSSCREEN: The enum member of type str.
        BULKCANCELCLIENTRESERVATIONS: The enum member of type str.
        FINDDUPLICATECLIENTS: The enum member of type str.
        MERGEDUPLICATECLIENTS: The enum member of type str.
        MANAGEAUTOEMAILS: The enum member of type str.
        MANAGEREVENUECATEGORIESFORSERVICES: The enum member of type str.
        MANAGEREVENUECATEGORIESFORPRODUCTS: The enum member of type str.
        ACCESSACTIVESESSIONTIMESSCREEN: The enum member of type str.
        ACCESSCLASSSESSIONTYPESCREENS: The enum member of type str.
        ACCESSSERVICECATEGORIESSCREEN: The enum member of type str.
        MANAGESUBSCRIBERPRICING: The enum member of type str.
        ADDINTROOFFERSONACQUISITIONDASHBOARD: The enum member of type str.
        MANAGEMINDBODYNETWORKSETTINGS: The enum member of type str.
        MANAGEPRODUCTS: The enum member of type str.
        VIEWPRODUCTCOST: The enum member of type str.
        MANAGEMEMBERSHIPSETTINGSFORPRICING: The enum member of type str.
        MANAGEPROMOTIONCODES: The enum member of type str.
        EDITSALES: The enum member of type str.
        PRINTPRODUCTBARCODES: The enum member of type str.
        MAKESALES: The enum member of type str.
        ADDPRODUCTSONRETAILSCREEN: The enum member of type str.
        EDITSALEDATEONRETAILSCREEN: The enum member of type str.
        EDITSALEPRICECOUNTONRETAILSCREEN: The enum member of type str.
        EDITACTIVATIONDATEONRETAILSCREEN: The enum member of type str.
        APPLYCUSTOMDISCOUNTSONRETAILSCREEN: The enum member of type str.
        PAYFORANOTHERCLIENTONRETAILSCREEN: The enum member of type str.
        VOIDEDITPASTSALES: The enum member of type str.
        REFUNDSALES: The enum member of type str.
        REFUNDSALESTOCREDITCARDS: The enum member of type str.
        LOCATIONSWITCHING: The enum member of type str.
        PULLREPORTSFORALLLOCATIONS: The enum member of type str.
        LOGINVENTORY: The enum member of type str.
        ADJUSTINVENTORY: The enum member of type str.
        TRANSFERINVENTORY: The enum member of type str.
        MANAGEPURCHASEORDERS: The enum member of type str.
        MANAGELOCATIONLOCALIZATION: The enum member of type str.
        MANAGEPERMISSIONGROUPS: The enum member of type str.
        MANAGECONSTANTCONTACTSETTINGS: The enum member of type str.
        ACCESSSERVICESPRICINGSCREEN: The enum member of type str.
        MANAGESEMESTERS: The enum member of type str.
        MANAGERETENTIONMARKETING: The enum member of type str.
        MANAGESUBSCRIBERSETUPCHECKLIST: The enum member of type str.
        VIEWCLASSANDEVENTRESERVATIONS: The enum member of type str.
        BOOKCLASSESANDEVENTS: The enum member of type str.
        BOOKCLASSESANDEVENTSINTHEPAST: The enum member of type str.
        BOOKCLASSESANDEVENTSWITHOUTPAYMENT: The enum member of type str.
        CANCELCLASSESANDEVENTS: The enum member of type str.
        MANAGECLASSNOTES: The enum member of type str.
        VIEWAPPOINTMENTSCHEDULE: The enum member of type str.
        VIEWPERSONALAPPOINTMENTSCHEDULE: The enum member of type str.
        EDITPERSONALAPPOINTMENTSCHEDULE: The enum member of type str.
        VIEWAPPOINTMENTDETAILS: The enum member of type str.
        MANAGEAPPOINTMENTREQUESTS: The enum member of type str.
        BOOKAPPOINTMENTSFOROTHERSTAFFMEMBERS: The enum member of type str.
        BOOKAPPOINTMENTSINTHEPAST: The enum member of type str.
        CHANGEAPPOINTMENTDETAILS: The enum member of type str.
        USEANYAPPOINTMENTASANADDON: The enum member of type str.
        CHANGEAPPOINTMENTDURATION: The enum member of type str.
        CANCELAPPOINTMENTS: The enum member of type str.
        APPLYPAYMENTTOAPPOINTMENTS: The enum member of type str.
        CHECKOUTAPPOINTMENTS: The enum member of type str.
        OVERRIDEASSIGNEDPRICING: The enum member of type str.
        MANAGEAPPOINTMENTCOLORS: The enum member of type str.
        VIEWALLLOCATIONONCLIENTLOOKUPSCREEN: The enum member of type str.
        ADDCLIENT: The enum member of type str.
        VIEWCLIENTPROFILESCREEN: The enum member of type str.
        EDITCLIENTPROFILESCREEN: The enum member of type str.
        ASSIGNCLIENTINDEXES: The enum member of type str.
        MANAGECLIENTSUSPENSIONS: The enum member of type str.
        VIEWCLIENTPASTVISITS: The enum member of type str.
        VIEWCLIENTACCOUNTANDPURCHASEHISTORY: The enum member of type str.
        EDITCLIENTSERVICEDURATIONANDASSIGNEDVISITS: The enum member of type str.
        EDITCLIENTSERVICESESSIONCOUNT: The enum member of type str.
        IGNORESERVICECATEGORIESWHENREASSIGNINGPAYMENT: The enum member of type str.
        VIEWCLIENTAUTOPAYSCHEDULES: The enum member of type str.
        MANAGECLIENTAUTOPAYSCHEDULES: The enum member of type str.
        VIEWCLIENTDOCUMENTS: The enum member of type str.
        ADDCLIENTDOCUMENTS: The enum member of type str.
        DELETECLIENTDOCUMENTS: The enum member of type str.
        VIEWCLIENTFUTUREVISITS: The enum member of type str.
        VIEWCLIENTBILLINGINFORMATION: The enum member of type str.
        EDITCLIENTBILLINGINFORMATION: The enum member of type str.
        MANAGECLIENTLOGINS: The enum member of type str.
        UNASSIGNCLIENTGIFTCARDS: The enum member of type str.
        IGNORECANCELLATIONPOLICY: The enum member of type str.
        LAUNCHSIGNINSCREEN: The enum member of type str.
        DELETEANDTERMINATECLIENTCONTRACTS: The enum member of type str.
        RELEASECONTRACTDEPOSITS: The enum member of type str.
        AUTORENEWANDSUSPENDCONTRACTS: The enum member of type str.
        MANAGECLASSTESTS: The enum member of type str.
        SCHEDULECLASSTESTS: The enum member of type str.
        MANAGECLIENTREQUIREDFIELDS: The enum member of type str.
        MANAGECLIENTALERTS: The enum member of type str.
        MANAGECLIENTTYPESANDCLIENTINDEXES: The enum member of type str.
        MANAGECLIENTREFERRALTYPES: The enum member of type str.
        MANAGECLIENTRELATIONSHIPTYPES: The enum member of type str.
        MANAGECLIENTGENDERS: The enum member of type str.
        CLIENTACQUISITIONANDANALYTICSDASHBOARDS: The enum member of type str.
        VIEWRETENTIONMARKETINGDASHBOARD: The enum member of type str.
        EXPORTREPORTS: The enum member of type str.
        MANAGETAGGEDCLIENTS: The enum member of type str.
        STAFFPHONEBOOKREPORT: The enum member of type str.
        SCHEDULEATAGLANCEREPORTFORALLSTAFF: The enum member of type str.
        PERSONALSCHEDULEATAGLANCEREPORT: The enum member of type str.
        ATTENDANCEWITHREVENUEREPORT: The enum member of type str.
        CANCELLATIONSREPORT: The enum member of type str.
        PERSONALCANCELLATIONSREPORT: The enum member of type str.
        ACCOUNTBALANCESREPORT: The enum member of type str.
        BULKAUTOPAYSCHEDULINGFROMACCOUNTBALANCESREPORT: The enum member of type str.
        EVENTINVOICESREPORT: The enum member of type str.
        CASHDRAWERREPORTCURRENTDATE: The enum member of type str.
        CASHDRAWERREPORTANYDATE: The enum member of type str.
        DAILYCLOSEOUTREPORT: The enum member of type str.
        SALESREPORTS: The enum member of type str.
        SALESBYSUPPLIERANDPRODUCTREPORTS: The enum member of type str.
        PROMOTEFEESREPORT: The enum member of type str.
        GIFTCARDSREPORT: The enum member of type str.
        INVENTORYREPORTS: The enum member of type str.
        MARKETINGREPORTS: The enum member of type str.
        ANALYSISREPORTS: The enum member of type str.
        CLIENTINDEXESREPORTS: The enum member of type str.
        PAYROLLREPORTSFORALLSTAFF: The enum member of type str.
        PERSONALPAYROLLREPORTS: The enum member of type str.
        STAFFPERFORMANCEREPORTS: The enum member of type str.
        ONLINEMETRICSREPORT: The enum member of type str.
        RETENTIONMANAGEMENTREPORT: The enum member of type str.
        ENTRYLOGSREPORT: The enum member of type str.
        STAFFACTIVITYLOGREPORT: The enum member of type str.
        MEMBERSHIPREPORT: The enum member of type str.
        MANAGEONLINEORDERSREPORT: The enum member of type str.
        TASKSREPORT: The enum member of type str.
        CLOCKSELFINANDOUT: The enum member of type str.
        CLOCKOTHERSINANDOUT: The enum member of type str.
        ACCESSTIMECLOCKREPORT: The enum member of type str.
        MANAGETIMECLOCKS: The enum member of type str.
        MANAGETIMECLOCKTASKS: The enum member of type str.
        MANAGECONTACTLOGTYPES: The enum member of type str.
        VIEWCONTACTLOGS: The enum member of type str.
        ADDCONTACTLOGS: The enum member of type str.
        EDITOTHERSTAFFMEMBERCONTACTLOGS: The enum member of type str.
        DELETECONTACTLOGS: The enum member of type str.
        CONTACTLOGANALYSISREPORT: The enum member of type str.
        SALESFORECASTREPORT: The enum member of type str.
        VIEWALLCLIENTS: The enum member of type str.
        MANAGECLIENTSALESREPS: The enum member of type str.
        CREATERETAILTICKETS: The enum member of type str.
        EDITRETAILTICKETS: The enum member of type str.
        MANAGETASKASSIGNMENTS: The enum member of type str.
        MERCHANTACCOUNTREPORTS: The enum member of type str.
        VOIDCREDITCARDTRANSACTIONS: The enum member of type str.
        SETTLECREDITCARDTRANSACTIONS: The enum member of type str.
        USESTOREDCREDITCARDS: The enum member of type str.
        MANAGEAUTOPAYS: The enum member of type str.
        VIEWPERSONALREVIEWS: The enum member of type str.
        VIEWOTHERSREVIEWS: The enum member of type str.
        VIEWCLIENTNAMESONREVIEWREPORT: The enum member of type str.
        EMAILCLIENTSFROMREVIEWREPORT: The enum member of type str.
        FLAGREVIEWFORREMOVAL: The enum member of type str.
        RESPONDPUBLICLYTOREVIEWS: The enum member of type str.

    """

    MANAGECLASSANDEVENTDESCRIPTIONS = "ManageClassAndEventDescriptions"

    MANAGECLASSSCHEDULES = "ManageClassSchedules"

    SCHEDULEFREECLASSESANDEVENTS = "ScheduleFreeClassesAndEvents"

    SCHEDULERESOURCESFORCLASSESANDEVENTS = "ScheduleResourcesForClassesAndEvents"

    SUBSTITUTECLASSANDEVENTTEACHERS = "SubstituteClassAndEventTeachers"

    BULKEDITCLASSSCHEDULES = "BulkEditClassSchedules"

    ADDSTAFFMEMBERS = "AddStaffMembers"

    MANAGEPERSONALINFOFORSTAFF = "ManagePersonalInfoForStaff"

    MANAGESTAFFSETTINGS = "ManageStaffSettings"

    MANAGESTAFFLOGINS = "ManageStaffLogins"

    MANAGESTAFFSCHEDULES = "ManageStaffSchedules"

    MANAGESTAFFPAYRATES = "ManageStaffPayRates"

    ACCESSBUSINESSINFORMATIONSCREEN = "AccessBusinessInformationScreen"

    ACCESSGENERALSETUPOPTIONSSCREEN = "AccessGeneralSetupOptionsScreen"

    ACCESSNEWSEVENTSSCREEN = "AccessNewsEventsScreen"

    MANAGEHOLIDAYS = "ManageHolidays"

    CLASSANDEVENTOPTIONSSCREEN = "ClassAndEventOptionsScreen"

    APPOINTMENTOPTIONSSCREEN = "AppointmentOptionsScreen"

    ACCESSMEDIAMANAGEMENTSCREEN = "AccessMediaManagementScreen"

    ACCESSMEMBERSHIPSETUPSCREEN = "AccessMembershipSetupScreen"

    MANAGEPAYMENTMETHODS = "ManagePaymentMethods"

    MANAGEROOMNUMBERS = "ManageRoomNumbers"

    ACCESSRESOURCEMANAGEMENTSCREEN = "AccessResourceManagementScreen"

    ACCESSRESOURCESSCHEDULINGTAB = "AccessResourcesSchedulingTab"

    ACCESSLINKSSCREEN = "AccessLinksScreen"

    BULKCANCELCLIENTRESERVATIONS = "BulkCancelClientReservations"

    FINDDUPLICATECLIENTS = "FindDuplicateClients"

    MERGEDUPLICATECLIENTS = "MergeDuplicateClients"

    MANAGEAUTOEMAILS = "ManageAutoEmails"

    MANAGEREVENUECATEGORIESFORSERVICES = "ManageRevenueCategoriesForServices"

    MANAGEREVENUECATEGORIESFORPRODUCTS = "ManageRevenueCategoriesForProducts"

    ACCESSACTIVESESSIONTIMESSCREEN = "AccessActiveSessionTimesScreen"

    ACCESSCLASSSESSIONTYPESCREENS = "AccessClassSessionTypeScreens"

    ACCESSSERVICECATEGORIESSCREEN = "AccessServiceCategoriesScreen"

    MANAGESUBSCRIBERPRICING = "ManageSubscriberPricing"

    ADDINTROOFFERSONACQUISITIONDASHBOARD = "AddIntroOffersOnAcquisitionDashboard"

    MANAGEMINDBODYNETWORKSETTINGS = "ManageMindbodyNetworkSettings"

    MANAGEPRODUCTS = "ManageProducts"

    VIEWPRODUCTCOST = "ViewProductCost"

    MANAGEMEMBERSHIPSETTINGSFORPRICING = "ManageMembershipSettingsForPricing"

    MANAGEPROMOTIONCODES = "ManagePromotionCodes"

    EDITSALES = "EditSales"

    PRINTPRODUCTBARCODES = "PrintProductBarcodes"

    MAKESALES = "MakeSales"

    ADDPRODUCTSONRETAILSCREEN = "AddProductsOnRetailScreen"

    EDITSALEDATEONRETAILSCREEN = "EditSaleDateOnRetailScreen"

    EDITSALEPRICECOUNTONRETAILSCREEN = "EditSalePriceCountOnRetailScreen"

    EDITACTIVATIONDATEONRETAILSCREEN = "EditActivationDateOnRetailScreen"

    APPLYCUSTOMDISCOUNTSONRETAILSCREEN = "ApplyCustomDiscountsOnRetailScreen"

    PAYFORANOTHERCLIENTONRETAILSCREEN = "PayForAnotherClientOnRetailScreen"

    VOIDEDITPASTSALES = "VoidEditPastSales"

    REFUNDSALES = "RefundSales"

    REFUNDSALESTOCREDITCARDS = "RefundSalesToCreditCards"

    LOCATIONSWITCHING = "LocationSwitching"

    PULLREPORTSFORALLLOCATIONS = "PullReportsForAllLocations"

    LOGINVENTORY = "LogInventory"

    ADJUSTINVENTORY = "AdjustInventory"

    TRANSFERINVENTORY = "TransferInventory"

    MANAGEPURCHASEORDERS = "ManagePurchaseOrders"

    MANAGELOCATIONLOCALIZATION = "ManageLocationLocalization"

    MANAGEPERMISSIONGROUPS = "ManagePermissionGroups"

    MANAGECONSTANTCONTACTSETTINGS = "ManageConstantContactSettings"

    ACCESSSERVICESPRICINGSCREEN = "AccessServicesPricingScreen"

    MANAGESEMESTERS = "ManageSemesters"

    MANAGERETENTIONMARKETING = "ManageRetentionMarketing"

    MANAGESUBSCRIBERSETUPCHECKLIST = "ManageSubscriberSetupChecklist"

    VIEWCLASSANDEVENTRESERVATIONS = "ViewClassAndEventReservations"

    BOOKCLASSESANDEVENTS = "BookClassesAndEvents"

    BOOKCLASSESANDEVENTSINTHEPAST = "BookClassesAndEventsInThePast"

    BOOKCLASSESANDEVENTSWITHOUTPAYMENT = "BookClassesAndEventsWithoutPayment"

    CANCELCLASSESANDEVENTS = "CancelClassesAndEvents"

    MANAGECLASSNOTES = "ManageClassNotes"

    VIEWAPPOINTMENTSCHEDULE = "ViewAppointmentSchedule"

    VIEWPERSONALAPPOINTMENTSCHEDULE = "ViewPersonalAppointmentSchedule"

    EDITPERSONALAPPOINTMENTSCHEDULE = "EditPersonalAppointmentSchedule"

    VIEWAPPOINTMENTDETAILS = "ViewAppointmentDetails"

    MANAGEAPPOINTMENTREQUESTS = "ManageAppointmentRequests"

    BOOKAPPOINTMENTSFOROTHERSTAFFMEMBERS = "BookAppointmentsForOtherStaffMembers"

    BOOKAPPOINTMENTSINTHEPAST = "BookAppointmentsInThePast"

    CHANGEAPPOINTMENTDETAILS = "ChangeAppointmentDetails"

    USEANYAPPOINTMENTASANADDON = "UseAnyAppointmentAsAnAddon"

    CHANGEAPPOINTMENTDURATION = "ChangeAppointmentDuration"

    CANCELAPPOINTMENTS = "CancelAppointments"

    APPLYPAYMENTTOAPPOINTMENTS = "ApplyPaymentToAppointments"

    CHECKOUTAPPOINTMENTS = "CheckOutAppointments"

    OVERRIDEASSIGNEDPRICING = "OverrideAssignedPricing"

    MANAGEAPPOINTMENTCOLORS = "ManageAppointmentColors"

    VIEWALLLOCATIONONCLIENTLOOKUPSCREEN = "ViewAllLocationOnClientLookupScreen"

    ADDCLIENT = "AddClient"

    VIEWCLIENTPROFILESCREEN = "ViewClientProfileScreen"

    EDITCLIENTPROFILESCREEN = "EditClientProfileScreen"

    ASSIGNCLIENTINDEXES = "AssignClientIndexes"

    MANAGECLIENTSUSPENSIONS = "ManageClientSuspensions"

    VIEWCLIENTPASTVISITS = "ViewClientPastVisits"

    VIEWCLIENTACCOUNTANDPURCHASEHISTORY = "ViewClientAccountAndPurchaseHistory"

    EDITCLIENTSERVICEDURATIONANDASSIGNEDVISITS = "EditClientServiceDurationAndAssignedVisits" # noqa: E501

    EDITCLIENTSERVICESESSIONCOUNT = "EditClientServiceSessionCount"

    IGNORESERVICECATEGORIESWHENREASSIGNINGPAYMENT = "IgnoreServiceCategoriesWhenReassigningPayment" # noqa: E501

    VIEWCLIENTAUTOPAYSCHEDULES = "ViewClientAutoPaySchedules"

    MANAGECLIENTAUTOPAYSCHEDULES = "ManageClientAutoPaySchedules"

    VIEWCLIENTDOCUMENTS = "ViewClientDocuments"

    ADDCLIENTDOCUMENTS = "AddClientDocuments"

    DELETECLIENTDOCUMENTS = "DeleteClientDocuments"

    VIEWCLIENTFUTUREVISITS = "ViewClientFutureVisits"

    VIEWCLIENTBILLINGINFORMATION = "ViewClientBillingInformation"

    EDITCLIENTBILLINGINFORMATION = "EditClientBillingInformation"

    MANAGECLIENTLOGINS = "ManageClientLogins"

    UNASSIGNCLIENTGIFTCARDS = "UnassignClientGiftCards"

    IGNORECANCELLATIONPOLICY = "IgnoreCancellationPolicy"

    LAUNCHSIGNINSCREEN = "LaunchSignInScreen"

    DELETEANDTERMINATECLIENTCONTRACTS = "DeleteAndTerminateClientContracts"

    RELEASECONTRACTDEPOSITS = "ReleaseContractDeposits"

    AUTORENEWANDSUSPENDCONTRACTS = "AutoRenewAndSuspendContracts"

    MANAGECLASSTESTS = "ManageClassTests"

    SCHEDULECLASSTESTS = "ScheduleClassTests"

    MANAGECLIENTREQUIREDFIELDS = "ManageClientRequiredFields"

    MANAGECLIENTALERTS = "ManageClientAlerts"

    MANAGECLIENTTYPESANDCLIENTINDEXES = "ManageClientTypesAndClientIndexes"

    MANAGECLIENTREFERRALTYPES = "ManageClientReferralTypes"

    MANAGECLIENTRELATIONSHIPTYPES = "ManageClientRelationshipTypes"

    MANAGECLIENTGENDERS = "ManageClientGenders"

    CLIENTACQUISITIONANDANALYTICSDASHBOARDS = "ClientAcquisitionAndAnalyticsDashboards"

    VIEWRETENTIONMARKETINGDASHBOARD = "ViewRetentionMarketingDashboard"

    EXPORTREPORTS = "ExportReports"

    MANAGETAGGEDCLIENTS = "ManageTaggedClients"

    STAFFPHONEBOOKREPORT = "StaffPhoneBookReport"

    SCHEDULEATAGLANCEREPORTFORALLSTAFF = "ScheduleAtAGlanceReportForAllStaff"

    PERSONALSCHEDULEATAGLANCEREPORT = "PersonalScheduleAtAGlanceReport"

    ATTENDANCEWITHREVENUEREPORT = "AttendanceWithRevenueReport"

    CANCELLATIONSREPORT = "CancellationsReport"

    PERSONALCANCELLATIONSREPORT = "PersonalCancellationsReport"

    ACCOUNTBALANCESREPORT = "AccountBalancesReport"

    BULKAUTOPAYSCHEDULINGFROMACCOUNTBALANCESREPORT = "BulkAutoPaySchedulingFromAccountBalancesReport" # noqa: E501

    EVENTINVOICESREPORT = "EventInvoicesReport"

    CASHDRAWERREPORTCURRENTDATE = "CashDrawerReportCurrentDate"

    CASHDRAWERREPORTANYDATE = "CashDrawerReportAnyDate"

    DAILYCLOSEOUTREPORT = "DailyCloseoutReport"

    SALESREPORTS = "SalesReports"

    SALESBYSUPPLIERANDPRODUCTREPORTS = "SalesBySupplierAndProductReports"

    PROMOTEFEESREPORT = "PromoteFeesReport"

    GIFTCARDSREPORT = "GiftCardsReport"

    INVENTORYREPORTS = "InventoryReports"

    MARKETINGREPORTS = "MarketingReports"

    ANALYSISREPORTS = "AnalysisReports"

    CLIENTINDEXESREPORTS = "ClientIndexesReports"

    PAYROLLREPORTSFORALLSTAFF = "PayrollReportsForAllStaff"

    PERSONALPAYROLLREPORTS = "PersonalPayrollReports"

    STAFFPERFORMANCEREPORTS = "StaffPerformanceReports"

    ONLINEMETRICSREPORT = "OnlineMetricsReport"

    RETENTIONMANAGEMENTREPORT = "RetentionManagementReport"

    ENTRYLOGSREPORT = "EntryLogsReport"

    STAFFACTIVITYLOGREPORT = "StaffActivityLogReport"

    MEMBERSHIPREPORT = "MembershipReport"

    MANAGEONLINEORDERSREPORT = "ManageOnlineOrdersReport"

    TASKSREPORT = "TasksReport"

    CLOCKSELFINANDOUT = "ClockSelfInAndOut"

    CLOCKOTHERSINANDOUT = "ClockOthersInAndOut"

    ACCESSTIMECLOCKREPORT = "AccessTimeclockReport"

    MANAGETIMECLOCKS = "ManageTimeClocks"

    MANAGETIMECLOCKTASKS = "ManageTimeClockTasks"

    MANAGECONTACTLOGTYPES = "ManageContactLogTypes"

    VIEWCONTACTLOGS = "ViewContactLogs"

    ADDCONTACTLOGS = "AddContactLogs"

    EDITOTHERSTAFFMEMBERCONTACTLOGS = "EditOtherStaffMemberContactLogs"

    DELETECONTACTLOGS = "DeleteContactLogs"

    CONTACTLOGANALYSISREPORT = "ContactLogAnalysisReport"

    SALESFORECASTREPORT = "SalesForecastReport"

    VIEWALLCLIENTS = "ViewAllClients"

    MANAGECLIENTSALESREPS = "ManageClientSalesReps"

    CREATERETAILTICKETS = "CreateRetailTickets"

    EDITRETAILTICKETS = "EditRetailTickets"

    MANAGETASKASSIGNMENTS = "ManageTaskAssignments"

    MERCHANTACCOUNTREPORTS = "MerchantAccountReports"

    VOIDCREDITCARDTRANSACTIONS = "VoidCreditCardTransactions"

    SETTLECREDITCARDTRANSACTIONS = "SettleCreditCardTransactions"

    USESTOREDCREDITCARDS = "UseStoredCreditCards"

    MANAGEAUTOPAYS = "ManageAutoPays"

    VIEWPERSONALREVIEWS = "ViewPersonalReviews"

    VIEWOTHERSREVIEWS = "ViewOthersReviews"

    VIEWCLIENTNAMESONREVIEWREPORT = "ViewClientNamesOnReviewReport"

    EMAILCLIENTSFROMREVIEWREPORT = "EmailClientsFromReviewReport"

    FLAGREVIEWFORREMOVAL = "FlagReviewForRemoval"

    RESPONDPUBLICLYTOREVIEWS = "RespondPubliclyToReviews"

    @classmethod
    def from_value(cls, value, default=None):
        """Return the matching enum value for the given input."""
        if value is None:
            return default

        # If numeric and matches directly
        if isinstance(value, int):
            for name, val in cls.__dict__.items():
                if not name.startswith("_") and val == value:
                    return val

        # If string, perform case-insensitive match
        if isinstance(value, str):
            value_lower = value.lower()
            for name, val in cls.__dict__.items():
                if not name.startswith("_") and (
                    name.lower() == value_lower or str(val).lower() == value_lower
                ):
                    return val

        # Fallback to default
        return default



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class RemoveClientFromClassRequest(object):
    """Implementation of the 'RemoveClientFromClassRequest' model.

    Attributes:
        client_id (str): The RSSID of the client to remove from the specified class.
        unique_client_id (int): The Unique Id of the client to remove from the
            specified class  Note: you need to provide the 'UniqueClientId' OR the
            'ClientId'. If both are provided, the 'UniqueClientId' takes precedence.
        class_id (int): The ID of the class that you want to remove the client from.
        test (bool): When `true`, the request ensures that its parameters are valid
            without affecting real data.<br />  When `false`, the request performs as
            intended and may affect live client data.<br />  Default: **false**
        send_email (bool): When `true`, indicates that the client should be sent an
            email. Depending on the site and client settings, an email may or may not
            be sent.<br />  Default: **false**  Note: When the Authorization header
            is passed and the SendEmail is set to `true`, then an email will be sent.
            When the Authorization header is passed and the SendEmail is set to
            `false`, then an email will not be sent.  When the Authorization header
            is not passed and the SendEmail is set to either `true` or `false`, then
            an email will not be sent.
        late_cancel (bool): When `true`, indicates that the client is to be late
            cancelled from the class.<br />  When `false`, indicates that the client
            is to be early cancelled from the class.<br />  Default: **false**
        visit_id (int): The ID of the client visit that you want to remove from the
            class.  Default: **0**

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "class_id": "ClassId",
        "client_id": "ClientId",
        "unique_client_id": "UniqueClientId",
        "test": "Test",
        "send_email": "SendEmail",
        "late_cancel": "LateCancel",
        "visit_id": "VisitId",
    }

    _optionals = [
        "client_id",
        "unique_client_id",
        "test",
        "send_email",
        "late_cancel",
        "visit_id",
    ]

    def __init__(
        self,
        class_id=None,
        client_id=APIHelper.SKIP,
        unique_client_id=APIHelper.SKIP,
        test=APIHelper.SKIP,
        send_email=APIHelper.SKIP,
        late_cancel=APIHelper.SKIP,
        visit_id=APIHelper.SKIP):
        """Initialize a RemoveClientFromClassRequest instance."""
        # Initialize members of the class
        if client_id is not APIHelper.SKIP:
            self.client_id = client_id
        if unique_client_id is not APIHelper.SKIP:
            self.unique_client_id = unique_client_id
        self.class_id = class_id
        if test is not APIHelper.SKIP:
            self.test = test
        if send_email is not APIHelper.SKIP:
            self.send_email = send_email
        if late_cancel is not APIHelper.SKIP:
            self.late_cancel = late_cancel
        if visit_id is not APIHelper.SKIP:
            self.visit_id = visit_id

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        class_id =\
            dictionary.get("ClassId")\
            if dictionary.get("ClassId")\
                else None
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else APIHelper.SKIP
        unique_client_id =\
            dictionary.get("UniqueClientId")\
            if dictionary.get("UniqueClientId")\
                else APIHelper.SKIP
        test =\
            dictionary.get("Test")\
            if "Test" in dictionary.keys()\
                else APIHelper.SKIP
        send_email =\
            dictionary.get("SendEmail")\
            if "SendEmail" in dictionary.keys()\
                else APIHelper.SKIP
        late_cancel =\
            dictionary.get("LateCancel")\
            if "LateCancel" in dictionary.keys()\
                else APIHelper.SKIP
        visit_id =\
            dictionary.get("VisitId")\
            if dictionary.get("VisitId")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(class_id,
                   client_id,
                   unique_client_id,
                   test,
                   send_email,
                   late_cancel,
                   visit_id)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _unique_client_id=(
            self.unique_client_id
            if hasattr(self, "unique_client_id")
            else None
        )
        _class_id=self.class_id
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        _send_email=(
            self.send_email
            if hasattr(self, "send_email")
            else None
        )
        _late_cancel=(
            self.late_cancel
            if hasattr(self, "late_cancel")
            else None
        )
        _visit_id=(
            self.visit_id
            if hasattr(self, "visit_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!r}, "
            f"unique_client_id={_unique_client_id!r}, "
            f"class_id={_class_id!r}, "
            f"test={_test!r}, "
            f"send_email={_send_email!r}, "
            f"late_cancel={_late_cancel!r}, "
            f"visit_id={_visit_id!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _unique_client_id=(
            self.unique_client_id
            if hasattr(self, "unique_client_id")
            else None
        )
        _class_id=self.class_id
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        _send_email=(
            self.send_email
            if hasattr(self, "send_email")
            else None
        )
        _late_cancel=(
            self.late_cancel
            if hasattr(self, "late_cancel")
            else None
        )
        _visit_id=(
            self.visit_id
            if hasattr(self, "visit_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!s}, "
            f"unique_client_id={_unique_client_id!s}, "
            f"class_id={_class_id!s}, "
            f"test={_test!s}, "
            f"send_email={_send_email!s}, "
            f"late_cancel={_late_cancel!s}, "
            f"visit_id={_visit_id!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class MobileProvider(object):
    """Implementation of the 'MobileProvider' model.

    Attributes:
        id (int): The model property of type int.
        active (bool): The model property of type bool.
        provider_name (str): The model property of type str.
        provider_address (str): The model property of type str.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": "Id",
        "active": "Active",
        "provider_name": "ProviderName",
        "provider_address": "ProviderAddress",
    }

    _optionals = [
        "id",
        "active",
        "provider_name",
        "provider_address",
    ]

    def __init__(
        self,
        id=APIHelper.SKIP,
        active=APIHelper.SKIP,
        provider_name=APIHelper.SKIP,
        provider_address=APIHelper.SKIP):
        """Initialize a MobileProvider instance."""
        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id
        if active is not APIHelper.SKIP:
            self.active = active
        if provider_name is not APIHelper.SKIP:
            self.provider_name = provider_name
        if provider_address is not APIHelper.SKIP:
            self.provider_address = provider_address

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        active =\
            dictionary.get("Active")\
            if "Active" in dictionary.keys()\
                else APIHelper.SKIP
        provider_name =\
            dictionary.get("ProviderName")\
            if dictionary.get("ProviderName")\
                else APIHelper.SKIP
        provider_address =\
            dictionary.get("ProviderAddress")\
            if dictionary.get("ProviderAddress")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(id,
                   active,
                   provider_name,
                   provider_address)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _active=(
            self.active
            if hasattr(self, "active")
            else None
        )
        _provider_name=(
            self.provider_name
            if hasattr(self, "provider_name")
            else None
        )
        _provider_address=(
            self.provider_address
            if hasattr(self, "provider_address")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!r}, "
            f"active={_active!r}, "
            f"provider_name={_provider_name!r}, "
            f"provider_address={_provider_address!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _active=(
            self.active
            if hasattr(self, "active")
            else None
        )
        _provider_name=(
            self.provider_name
            if hasattr(self, "provider_name")
            else None
        )
        _provider_address=(
            self.provider_address
            if hasattr(self, "provider_address")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!s}, "
            f"active={_active!s}, "
            f"provider_name={_provider_name!s}, "
            f"provider_address={_provider_address!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501

class ScheduleType3Enum(object):
    """Implementation of the 'ScheduleType3' enum.

    A schedule type used to filter the returned results. Possible values are:
    * All
    * Class
    * Enrollment
    * Appointment
    * Resource
    * Media
    * Arrival

    Attributes:
        ALL: The enum member of type str.
        CLASS: The enum member of type str.
        ENROLLMENT: The enum member of type str.
        APPOINTMENT: The enum member of type str.
        RESOURCE: The enum member of type str.
        MEDIA: The enum member of type str.
        ARRIVAL: The enum member of type str.

    """

    ALL = "All"

    CLASS = "Class"

    ENROLLMENT = "Enrollment"

    APPOINTMENT = "Appointment"

    RESOURCE = "Resource"

    MEDIA = "Media"

    ARRIVAL = "Arrival"

    @classmethod
    def from_value(cls, value, default=None):
        """Return the matching enum value for the given input."""
        if value is None:
            return default

        # If numeric and matches directly
        if isinstance(value, int):
            for name, val in cls.__dict__.items():
                if not name.startswith("_") and val == value:
                    return val

        # If string, perform case-insensitive match
        if isinstance(value, str):
            value_lower = value.lower()
            for name, val in cls.__dict__.items():
                if not name.startswith("_") and (
                    name.lower() == value_lower or str(val).lower() == value_lower
                ):
                    return val

        # Fallback to default
        return default



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.client_membership import (
    ClientMembership,
)


class ClientMemberships(object):
    """Implementation of the 'ClientMemberships' model.

    Attributes:
        client_id (str): ID of the client.
        memberships (List[ClientMembership]): Contains information about the Client
            Memberships details.
        error_message (str): The model property of type str.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "client_id": "ClientId",
        "memberships": "Memberships",
        "error_message": "ErrorMessage",
    }

    _optionals = [
        "client_id",
        "memberships",
        "error_message",
    ]

    def __init__(
        self,
        client_id=APIHelper.SKIP,
        memberships=APIHelper.SKIP,
        error_message=APIHelper.SKIP):
        """Initialize a ClientMemberships instance."""
        # Initialize members of the class
        if client_id is not APIHelper.SKIP:
            self.client_id = client_id
        if memberships is not APIHelper.SKIP:
            self.memberships = memberships
        if error_message is not APIHelper.SKIP:
            self.error_message = error_message

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else APIHelper.SKIP
        memberships = None
        if dictionary.get("Memberships") is not None:
            memberships = [
                ClientMembership.from_dictionary(x)
                    for x in dictionary.get("Memberships")
            ]
        else:
            memberships = APIHelper.SKIP
        error_message =\
            dictionary.get("ErrorMessage")\
            if dictionary.get("ErrorMessage")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(client_id,
                   memberships,
                   error_message)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _memberships=(
            self.memberships
            if hasattr(self, "memberships")
            else None
        )
        _error_message=(
            self.error_message
            if hasattr(self, "error_message")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!r}, "
            f"memberships={_memberships!r}, "
            f"error_message={_error_message!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _memberships=(
            self.memberships
            if hasattr(self, "memberships")
            else None
        )
        _error_message=(
            self.error_message
            if hasattr(self, "error_message")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!s}, "
            f"memberships={_memberships!s}, "
            f"error_message={_error_message!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class CommissionDetail(object):
    """Implementation of the 'CommissionDetail' model.

    Attributes:
        commission_type (str): The type of commission earned. Possible values are:  *
            ItemStandardPercentageCommission  * ItemStandardFlatCommission  *
            ItemPromotionalPercentageCommission  * ItemPromotionalFlatCommission  *
            StaffStandardPercentageCommission  * StaffStandardFlatCommission  *
            StaffPromotionalPercentageCommission  * StaffPromotionalFlatCommission
        commission_earnings (float): The portion of `Earnings` earned by this
            `CommissionType`.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "commission_type": "CommissionType",
        "commission_earnings": "CommissionEarnings",
    }

    _optionals = [
        "commission_type",
        "commission_earnings",
    ]

    def __init__(
        self,
        commission_type=APIHelper.SKIP,
        commission_earnings=APIHelper.SKIP):
        """Initialize a CommissionDetail instance."""
        # Initialize members of the class
        if commission_type is not APIHelper.SKIP:
            self.commission_type = commission_type
        if commission_earnings is not APIHelper.SKIP:
            self.commission_earnings = commission_earnings

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        commission_type =\
            dictionary.get("CommissionType")\
            if dictionary.get("CommissionType")\
                else APIHelper.SKIP
        commission_earnings =\
            dictionary.get("CommissionEarnings")\
            if dictionary.get("CommissionEarnings")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(commission_type,
                   commission_earnings)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _commission_type=(
            self.commission_type
            if hasattr(self, "commission_type")
            else None
        )
        _commission_earnings=(
            self.commission_earnings
            if hasattr(self, "commission_earnings")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"commission_type={_commission_type!r}, "
            f"commission_earnings={_commission_earnings!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _commission_type=(
            self.commission_type
            if hasattr(self, "commission_type")
            else None
        )
        _commission_earnings=(
            self.commission_earnings
            if hasattr(self, "commission_earnings")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"commission_type={_commission_type!s}, "
            f"commission_earnings={_commission_earnings!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class ProductsInventory(object):
    """Implementation of the 'ProductsInventory' model.

    Attributes:
        product_id (int): A ProductId of the product.
        barcode_id (str): The Id is barcode Id of the product.
        location_id (int): The LocationId of the product.
        units_logged (int): UnitsLogged of the product.
        units_sold (int): UnitsSold of the product.
        units_in_stock (int): The units in stock of the product
        reorder_level (int): ReorderLevel of the product.
        max_level (int): MaxLevel of the product.
        created_date_time_utc (datetime): CreatedDateTimeUTC of the product.
        modified_date_time_utc (datetime): ModifiedDateTimeUTC of the product.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "product_id": "ProductId",
        "barcode_id": "BarcodeId",
        "location_id": "LocationId",
        "units_logged": "UnitsLogged",
        "units_sold": "UnitsSold",
        "units_in_stock": "UnitsInStock",
        "reorder_level": "ReorderLevel",
        "max_level": "MaxLevel",
        "created_date_time_utc": "CreatedDateTimeUTC",
        "modified_date_time_utc": "ModifiedDateTimeUTC",
    }

    _optionals = [
        "product_id",
        "barcode_id",
        "location_id",
        "units_logged",
        "units_sold",
        "units_in_stock",
        "reorder_level",
        "max_level",
        "created_date_time_utc",
        "modified_date_time_utc",
    ]

    def __init__(
        self,
        product_id=APIHelper.SKIP,
        barcode_id=APIHelper.SKIP,
        location_id=APIHelper.SKIP,
        units_logged=APIHelper.SKIP,
        units_sold=APIHelper.SKIP,
        units_in_stock=APIHelper.SKIP,
        reorder_level=APIHelper.SKIP,
        max_level=APIHelper.SKIP,
        created_date_time_utc=APIHelper.SKIP,
        modified_date_time_utc=APIHelper.SKIP):
        """Initialize a ProductsInventory instance."""
        # Initialize members of the class
        if product_id is not APIHelper.SKIP:
            self.product_id = product_id
        if barcode_id is not APIHelper.SKIP:
            self.barcode_id = barcode_id
        if location_id is not APIHelper.SKIP:
            self.location_id = location_id
        if units_logged is not APIHelper.SKIP:
            self.units_logged = units_logged
        if units_sold is not APIHelper.SKIP:
            self.units_sold = units_sold
        if units_in_stock is not APIHelper.SKIP:
            self.units_in_stock = units_in_stock
        if reorder_level is not APIHelper.SKIP:
            self.reorder_level = reorder_level
        if max_level is not APIHelper.SKIP:
            self.max_level = max_level
        if created_date_time_utc is not APIHelper.SKIP:
            self.created_date_time_utc =\
                 APIHelper.apply_datetime_converter(
                created_date_time_utc, APIHelper.RFC3339DateTime)\
                 if created_date_time_utc else None
        if modified_date_time_utc is not APIHelper.SKIP:
            self.modified_date_time_utc =\
                 APIHelper.apply_datetime_converter(
                modified_date_time_utc, APIHelper.RFC3339DateTime)\
                 if modified_date_time_utc else None

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        product_id =\
            dictionary.get("ProductId")\
            if dictionary.get("ProductId")\
                else APIHelper.SKIP
        barcode_id =\
            dictionary.get("BarcodeId")\
            if dictionary.get("BarcodeId")\
                else APIHelper.SKIP
        location_id =\
            dictionary.get("LocationId")\
            if dictionary.get("LocationId")\
                else APIHelper.SKIP
        units_logged =\
            dictionary.get("UnitsLogged")\
            if dictionary.get("UnitsLogged")\
                else APIHelper.SKIP
        units_sold =\
            dictionary.get("UnitsSold")\
            if dictionary.get("UnitsSold")\
                else APIHelper.SKIP
        units_in_stock =\
            dictionary.get("UnitsInStock")\
            if dictionary.get("UnitsInStock")\
                else APIHelper.SKIP
        reorder_level =\
            dictionary.get("ReorderLevel")\
            if dictionary.get("ReorderLevel")\
                else APIHelper.SKIP
        max_level =\
            dictionary.get("MaxLevel")\
            if dictionary.get("MaxLevel")\
                else APIHelper.SKIP
        created_date_time_utc = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("CreatedDateTimeUTC")).datetime\
            if dictionary.get("CreatedDateTimeUTC") else APIHelper.SKIP
        modified_date_time_utc = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("ModifiedDateTimeUTC")).datetime\
            if dictionary.get("ModifiedDateTimeUTC") else APIHelper.SKIP

        # Return an object of this model
        return cls(product_id,
                   barcode_id,
                   location_id,
                   units_logged,
                   units_sold,
                   units_in_stock,
                   reorder_level,
                   max_level,
                   created_date_time_utc,
                   modified_date_time_utc)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _product_id=(
            self.product_id
            if hasattr(self, "product_id")
            else None
        )
        _barcode_id=(
            self.barcode_id
            if hasattr(self, "barcode_id")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _units_logged=(
            self.units_logged
            if hasattr(self, "units_logged")
            else None
        )
        _units_sold=(
            self.units_sold
            if hasattr(self, "units_sold")
            else None
        )
        _units_in_stock=(
            self.units_in_stock
            if hasattr(self, "units_in_stock")
            else None
        )
        _reorder_level=(
            self.reorder_level
            if hasattr(self, "reorder_level")
            else None
        )
        _max_level=(
            self.max_level
            if hasattr(self, "max_level")
            else None
        )
        _created_date_time_utc=(
            self.created_date_time_utc
            if hasattr(self, "created_date_time_utc")
            else None
        )
        _modified_date_time_utc=(
            self.modified_date_time_utc
            if hasattr(self, "modified_date_time_utc")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"product_id={_product_id!r}, "
            f"barcode_id={_barcode_id!r}, "
            f"location_id={_location_id!r}, "
            f"units_logged={_units_logged!r}, "
            f"units_sold={_units_sold!r}, "
            f"units_in_stock={_units_in_stock!r}, "
            f"reorder_level={_reorder_level!r}, "
            f"max_level={_max_level!r}, "
            f"created_date_time_utc={_created_date_time_utc!r}, "
            f"modified_date_time_utc={_modified_date_time_utc!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _product_id=(
            self.product_id
            if hasattr(self, "product_id")
            else None
        )
        _barcode_id=(
            self.barcode_id
            if hasattr(self, "barcode_id")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _units_logged=(
            self.units_logged
            if hasattr(self, "units_logged")
            else None
        )
        _units_sold=(
            self.units_sold
            if hasattr(self, "units_sold")
            else None
        )
        _units_in_stock=(
            self.units_in_stock
            if hasattr(self, "units_in_stock")
            else None
        )
        _reorder_level=(
            self.reorder_level
            if hasattr(self, "reorder_level")
            else None
        )
        _max_level=(
            self.max_level
            if hasattr(self, "max_level")
            else None
        )
        _created_date_time_utc=(
            self.created_date_time_utc
            if hasattr(self, "created_date_time_utc")
            else None
        )
        _modified_date_time_utc=(
            self.modified_date_time_utc
            if hasattr(self, "modified_date_time_utc")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"product_id={_product_id!s}, "
            f"barcode_id={_barcode_id!s}, "
            f"location_id={_location_id!s}, "
            f"units_logged={_units_logged!s}, "
            f"units_sold={_units_sold!s}, "
            f"units_in_stock={_units_in_stock!s}, "
            f"reorder_level={_reorder_level!s}, "
            f"max_level={_max_level!s}, "
            f"created_date_time_utc={_created_date_time_utc!s}, "
            f"modified_date_time_utc={_modified_date_time_utc!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.pagination import (
    Pagination,
)
from mindbodypublicapi.models.reservation import (
    Reservation,
)
from mindbodypublicapi.models.response_details import (
    ResponseDetails,
)


class GetReservationResponse(object):
    """Implementation of the 'GetReservationResponse' model.

    Contains information about the get reservation response

    Attributes:
        reservations (List[Reservation]): Contains information about the reservation
            details.
        pagination (Pagination): Contains information about the pagination used.
        response_details (ResponseDetails): Contains information about the response
            message detail.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "reservations": "Reservations",
        "pagination": "Pagination",
        "response_details": "ResponseDetails",
    }

    _optionals = [
        "reservations",
        "pagination",
        "response_details",
    ]

    def __init__(
        self,
        reservations=APIHelper.SKIP,
        pagination=APIHelper.SKIP,
        response_details=APIHelper.SKIP):
        """Initialize a GetReservationResponse instance."""
        # Initialize members of the class
        if reservations is not APIHelper.SKIP:
            self.reservations = reservations
        if pagination is not APIHelper.SKIP:
            self.pagination = pagination
        if response_details is not APIHelper.SKIP:
            self.response_details = response_details

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        reservations = None
        if dictionary.get("Reservations") is not None:
            reservations = [
                Reservation.from_dictionary(x)
                    for x in dictionary.get("Reservations")
            ]
        else:
            reservations = APIHelper.SKIP
        pagination =\
            Pagination.from_dictionary(
                dictionary.get("Pagination"))\
                if "Pagination" in dictionary.keys()\
                else APIHelper.SKIP
        response_details =\
            ResponseDetails.from_dictionary(
                dictionary.get("ResponseDetails"))\
                if "ResponseDetails" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(reservations,
                   pagination,
                   response_details)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _reservations=(
            self.reservations
            if hasattr(self, "reservations")
            else None
        )
        _pagination=(
            self.pagination
            if hasattr(self, "pagination")
            else None
        )
        _response_details=(
            self.response_details
            if hasattr(self, "response_details")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"reservations={_reservations!r}, "
            f"pagination={_pagination!r}, "
            f"response_details={_response_details!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _reservations=(
            self.reservations
            if hasattr(self, "reservations")
            else None
        )
        _pagination=(
            self.pagination
            if hasattr(self, "pagination")
            else None
        )
        _response_details=(
            self.response_details
            if hasattr(self, "response_details")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"reservations={_reservations!s}, "
            f"pagination={_pagination!s}, "
            f"response_details={_response_details!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class UpdateClientVisitRequest(object):
    """Implementation of the 'UpdateClientVisitRequest' model.

    Attributes:
        visit_id (int): The ID of the visit to be updated.
        makeup (bool): When `true`, indicates that the visit is eligible to be made
            up.
        signed_in (bool): When `true`, indicates that the client has signed in for
            the visit.
        client_service_id (int): The ID of the service to assign to the visit.
        execute (str): The execute code used to update this visit. Possible values
            are:  * Cancel  * Latecancel  * Unlatecancel
        test (bool): When `true`, indicates that test mode is enabled. When test mode
            is enabled, input information is validated, but not committed.<br />
            Default: **false**
        send_email (bool): When `true`, indicates that the client should be sent an
            email for cancellations. Note that email is not sent unless the client
            has an email address and automatic emails have been set up correctly.<br
            />  Default: **false**

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "visit_id": "VisitId",
        "makeup": "Makeup",
        "signed_in": "SignedIn",
        "client_service_id": "ClientServiceId",
        "execute": "Execute",
        "test": "Test",
        "send_email": "SendEmail",
    }

    _optionals = [
        "makeup",
        "signed_in",
        "client_service_id",
        "execute",
        "test",
        "send_email",
    ]

    def __init__(
        self,
        visit_id=None,
        makeup=APIHelper.SKIP,
        signed_in=APIHelper.SKIP,
        client_service_id=APIHelper.SKIP,
        execute=APIHelper.SKIP,
        test=APIHelper.SKIP,
        send_email=APIHelper.SKIP):
        """Initialize a UpdateClientVisitRequest instance."""
        # Initialize members of the class
        self.visit_id = visit_id
        if makeup is not APIHelper.SKIP:
            self.makeup = makeup
        if signed_in is not APIHelper.SKIP:
            self.signed_in = signed_in
        if client_service_id is not APIHelper.SKIP:
            self.client_service_id = client_service_id
        if execute is not APIHelper.SKIP:
            self.execute = execute
        if test is not APIHelper.SKIP:
            self.test = test
        if send_email is not APIHelper.SKIP:
            self.send_email = send_email

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        visit_id =\
            dictionary.get("VisitId")\
            if dictionary.get("VisitId")\
                else None
        makeup =\
            dictionary.get("Makeup")\
            if "Makeup" in dictionary.keys()\
                else APIHelper.SKIP
        signed_in =\
            dictionary.get("SignedIn")\
            if "SignedIn" in dictionary.keys()\
                else APIHelper.SKIP
        client_service_id =\
            dictionary.get("ClientServiceId")\
            if dictionary.get("ClientServiceId")\
                else APIHelper.SKIP
        execute =\
            dictionary.get("Execute")\
            if dictionary.get("Execute")\
                else APIHelper.SKIP
        test =\
            dictionary.get("Test")\
            if "Test" in dictionary.keys()\
                else APIHelper.SKIP
        send_email =\
            dictionary.get("SendEmail")\
            if "SendEmail" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(visit_id,
                   makeup,
                   signed_in,
                   client_service_id,
                   execute,
                   test,
                   send_email)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _visit_id=self.visit_id
        _makeup=(
            self.makeup
            if hasattr(self, "makeup")
            else None
        )
        _signed_in=(
            self.signed_in
            if hasattr(self, "signed_in")
            else None
        )
        _client_service_id=(
            self.client_service_id
            if hasattr(self, "client_service_id")
            else None
        )
        _execute=(
            self.execute
            if hasattr(self, "execute")
            else None
        )
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        _send_email=(
            self.send_email
            if hasattr(self, "send_email")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"visit_id={_visit_id!r}, "
            f"makeup={_makeup!r}, "
            f"signed_in={_signed_in!r}, "
            f"client_service_id={_client_service_id!r}, "
            f"execute={_execute!r}, "
            f"test={_test!r}, "
            f"send_email={_send_email!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _visit_id=self.visit_id
        _makeup=(
            self.makeup
            if hasattr(self, "makeup")
            else None
        )
        _signed_in=(
            self.signed_in
            if hasattr(self, "signed_in")
            else None
        )
        _client_service_id=(
            self.client_service_id
            if hasattr(self, "client_service_id")
            else None
        )
        _execute=(
            self.execute
            if hasattr(self, "execute")
            else None
        )
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        _send_email=(
            self.send_email
            if hasattr(self, "send_email")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"visit_id={_visit_id!s}, "
            f"makeup={_makeup!s}, "
            f"signed_in={_signed_in!s}, "
            f"client_service_id={_client_service_id!s}, "
            f"execute={_execute!s}, "
            f"test={_test!s}, "
            f"send_email={_send_email!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class TimeCardEvent(object):
    """Implementation of the 'TimeCardEvent' model.

    Attributes:
        staff_id (int): The ID of the requested staff member.
        task (str): The staff member’s job title.
        time_in (datetime): The time that the staff member started the job task.
        time_out (datetime): The time that the staff member stopped doing the job
            task.
        hours (float): The number of hours on this time card, rounded to the nearest
            fourth decimal place.
        hourly_rate (float): The hourly rate the business pays this staff for this
            `Task`.
        earnings (float): The total amount earned by the staff member for this time
            card entry.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "staff_id": "StaffId",
        "task": "Task",
        "time_in": "TimeIn",
        "time_out": "TimeOut",
        "hours": "Hours",
        "hourly_rate": "HourlyRate",
        "earnings": "Earnings",
    }

    _optionals = [
        "staff_id",
        "task",
        "time_in",
        "time_out",
        "hours",
        "hourly_rate",
        "earnings",
    ]

    def __init__(
        self,
        staff_id=APIHelper.SKIP,
        task=APIHelper.SKIP,
        time_in=APIHelper.SKIP,
        time_out=APIHelper.SKIP,
        hours=APIHelper.SKIP,
        hourly_rate=APIHelper.SKIP,
        earnings=APIHelper.SKIP):
        """Initialize a TimeCardEvent instance."""
        # Initialize members of the class
        if staff_id is not APIHelper.SKIP:
            self.staff_id = staff_id
        if task is not APIHelper.SKIP:
            self.task = task
        if time_in is not APIHelper.SKIP:
            self.time_in =\
                 APIHelper.apply_datetime_converter(
                time_in, APIHelper.RFC3339DateTime)\
                 if time_in else None
        if time_out is not APIHelper.SKIP:
            self.time_out =\
                 APIHelper.apply_datetime_converter(
                time_out, APIHelper.RFC3339DateTime)\
                 if time_out else None
        if hours is not APIHelper.SKIP:
            self.hours = hours
        if hourly_rate is not APIHelper.SKIP:
            self.hourly_rate = hourly_rate
        if earnings is not APIHelper.SKIP:
            self.earnings = earnings

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        staff_id =\
            dictionary.get("StaffId")\
            if dictionary.get("StaffId")\
                else APIHelper.SKIP
        task =\
            dictionary.get("Task")\
            if dictionary.get("Task")\
                else APIHelper.SKIP
        time_in = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("TimeIn")).datetime\
            if dictionary.get("TimeIn") else APIHelper.SKIP
        time_out = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("TimeOut")).datetime\
            if dictionary.get("TimeOut") else APIHelper.SKIP
        hours =\
            dictionary.get("Hours")\
            if dictionary.get("Hours")\
                else APIHelper.SKIP
        hourly_rate =\
            dictionary.get("HourlyRate")\
            if dictionary.get("HourlyRate")\
                else APIHelper.SKIP
        earnings =\
            dictionary.get("Earnings")\
            if dictionary.get("Earnings")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(staff_id,
                   task,
                   time_in,
                   time_out,
                   hours,
                   hourly_rate,
                   earnings)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _task=(
            self.task
            if hasattr(self, "task")
            else None
        )
        _time_in=(
            self.time_in
            if hasattr(self, "time_in")
            else None
        )
        _time_out=(
            self.time_out
            if hasattr(self, "time_out")
            else None
        )
        _hours=(
            self.hours
            if hasattr(self, "hours")
            else None
        )
        _hourly_rate=(
            self.hourly_rate
            if hasattr(self, "hourly_rate")
            else None
        )
        _earnings=(
            self.earnings
            if hasattr(self, "earnings")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"staff_id={_staff_id!r}, "
            f"task={_task!r}, "
            f"time_in={_time_in!r}, "
            f"time_out={_time_out!r}, "
            f"hours={_hours!r}, "
            f"hourly_rate={_hourly_rate!r}, "
            f"earnings={_earnings!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _task=(
            self.task
            if hasattr(self, "task")
            else None
        )
        _time_in=(
            self.time_in
            if hasattr(self, "time_in")
            else None
        )
        _time_out=(
            self.time_out
            if hasattr(self, "time_out")
            else None
        )
        _hours=(
            self.hours
            if hasattr(self, "hours")
            else None
        )
        _hourly_rate=(
            self.hourly_rate
            if hasattr(self, "hourly_rate")
            else None
        )
        _earnings=(
            self.earnings
            if hasattr(self, "earnings")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"staff_id={_staff_id!s}, "
            f"task={_task!s}, "
            f"time_in={_time_in!s}, "
            f"time_out={_time_out!s}, "
            f"hours={_hours!s}, "
            f"hourly_rate={_hourly_rate!s}, "
            f"earnings={_earnings!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetTransactionsRequest(object):
    """Implementation of the 'GetTransactionsRequest' model.

    Transactions Request

    Attributes:
        sale_id (int): Filters the transaction results with the ID number associated
            with the sale.
        transaction_id (int): Filters the transaction results with the ID number
            generated when the sale is processed.
        client_id (int): Filters results to the requested client ID.
        location_id (int): Filters the transaction results with the ID number
            associated with the location of the sale.
        status (str): Filters the transaction results by the estimated transaction
            status.
        transaction_start_date_time (datetime): Filters the transaction results that
            happpened after this date and time.   Default: **today’s date**
        transaction_end_date_time (datetime): Filters the transaction results that
            happpened before this date and time.   Default: **today’s date**
        limit (int): Number of results to include, defaults to 100
        offset (int): Page offset, defaults to 0.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "sale_id": "SaleId",
        "transaction_id": "TransactionId",
        "client_id": "ClientId",
        "location_id": "LocationId",
        "status": "Status",
        "transaction_start_date_time": "TransactionStartDateTime",
        "transaction_end_date_time": "TransactionEndDateTime",
        "limit": "Limit",
        "offset": "Offset",
    }

    _optionals = [
        "sale_id",
        "transaction_id",
        "client_id",
        "location_id",
        "status",
        "transaction_start_date_time",
        "transaction_end_date_time",
        "limit",
        "offset",
    ]

    def __init__(
        self,
        sale_id=APIHelper.SKIP,
        transaction_id=APIHelper.SKIP,
        client_id=APIHelper.SKIP,
        location_id=APIHelper.SKIP,
        status=APIHelper.SKIP,
        transaction_start_date_time=APIHelper.SKIP,
        transaction_end_date_time=APIHelper.SKIP,
        limit=APIHelper.SKIP,
        offset=APIHelper.SKIP):
        """Initialize a GetTransactionsRequest instance."""
        # Initialize members of the class
        if sale_id is not APIHelper.SKIP:
            self.sale_id = sale_id
        if transaction_id is not APIHelper.SKIP:
            self.transaction_id = transaction_id
        if client_id is not APIHelper.SKIP:
            self.client_id = client_id
        if location_id is not APIHelper.SKIP:
            self.location_id = location_id
        if status is not APIHelper.SKIP:
            self.status = status
        if transaction_start_date_time is not APIHelper.SKIP:
            self.transaction_start_date_time =\
                 APIHelper.apply_datetime_converter(
                transaction_start_date_time, APIHelper.RFC3339DateTime)\
                 if transaction_start_date_time else None
        if transaction_end_date_time is not APIHelper.SKIP:
            self.transaction_end_date_time =\
                 APIHelper.apply_datetime_converter(
                transaction_end_date_time, APIHelper.RFC3339DateTime)\
                 if transaction_end_date_time else None
        if limit is not APIHelper.SKIP:
            self.limit = limit
        if offset is not APIHelper.SKIP:
            self.offset = offset

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        sale_id =\
            dictionary.get("SaleId")\
            if dictionary.get("SaleId")\
                else APIHelper.SKIP
        transaction_id =\
            dictionary.get("TransactionId")\
            if dictionary.get("TransactionId")\
                else APIHelper.SKIP
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else APIHelper.SKIP
        location_id =\
            dictionary.get("LocationId")\
            if dictionary.get("LocationId")\
                else APIHelper.SKIP
        status =\
            dictionary.get("Status")\
            if dictionary.get("Status")\
                else APIHelper.SKIP
        transaction_start_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("TransactionStartDateTime")).datetime\
            if dictionary.get("TransactionStartDateTime") else APIHelper.SKIP
        transaction_end_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("TransactionEndDateTime")).datetime\
            if dictionary.get("TransactionEndDateTime") else APIHelper.SKIP
        limit =\
            dictionary.get("Limit")\
            if dictionary.get("Limit")\
                else APIHelper.SKIP
        offset =\
            dictionary.get("Offset")\
            if dictionary.get("Offset")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(sale_id,
                   transaction_id,
                   client_id,
                   location_id,
                   status,
                   transaction_start_date_time,
                   transaction_end_date_time,
                   limit,
                   offset)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _sale_id=(
            self.sale_id
            if hasattr(self, "sale_id")
            else None
        )
        _transaction_id=(
            self.transaction_id
            if hasattr(self, "transaction_id")
            else None
        )
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _status=(
            self.status
            if hasattr(self, "status")
            else None
        )
        _transaction_start_date_time=(
            self.transaction_start_date_time
            if hasattr(self, "transaction_start_date_time")
            else None
        )
        _transaction_end_date_time=(
            self.transaction_end_date_time
            if hasattr(self, "transaction_end_date_time")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"sale_id={_sale_id!r}, "
            f"transaction_id={_transaction_id!r}, "
            f"client_id={_client_id!r}, "
            f"location_id={_location_id!r}, "
            f"status={_status!r}, "
            f"transaction_start_date_time={_transaction_start_date_time!r}, "
            f"transaction_end_date_time={_transaction_end_date_time!r}, "
            f"limit={_limit!r}, "
            f"offset={_offset!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _sale_id=(
            self.sale_id
            if hasattr(self, "sale_id")
            else None
        )
        _transaction_id=(
            self.transaction_id
            if hasattr(self, "transaction_id")
            else None
        )
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _status=(
            self.status
            if hasattr(self, "status")
            else None
        )
        _transaction_start_date_time=(
            self.transaction_start_date_time
            if hasattr(self, "transaction_start_date_time")
            else None
        )
        _transaction_end_date_time=(
            self.transaction_end_date_time
            if hasattr(self, "transaction_end_date_time")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"sale_id={_sale_id!s}, "
            f"transaction_id={_transaction_id!s}, "
            f"client_id={_client_id!s}, "
            f"location_id={_location_id!s}, "
            f"status={_status!s}, "
            f"transaction_start_date_time={_transaction_start_date_time!s}, "
            f"transaction_end_date_time={_transaction_end_date_time!s}, "
            f"limit={_limit!s}, "
            f"offset={_offset!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetResourcesRequest(object):
    """Implementation of the 'GetResourcesRequest' model.

    Attributes:
        resource_ids (List[int]): Filter on resourceIds
        location_ids (List[int]): Filter by location ids (optional)
        schedule_types (List[ScheduleType4Enum]): Filter by schedule types (optional)
        program_ids (List[int]): Filter by program ids (optional)
        include_inactive (bool): Enable to include inactive
        limit (int): Number of results to include, defaults to 100
        offset (int): Page offset, defaults to 0.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "resource_ids": "ResourceIds",
        "location_ids": "LocationIds",
        "schedule_types": "ScheduleTypes",
        "program_ids": "ProgramIds",
        "include_inactive": "IncludeInactive",
        "limit": "Limit",
        "offset": "Offset",
    }

    _optionals = [
        "resource_ids",
        "location_ids",
        "schedule_types",
        "program_ids",
        "include_inactive",
        "limit",
        "offset",
    ]

    def __init__(
        self,
        resource_ids=APIHelper.SKIP,
        location_ids=APIHelper.SKIP,
        schedule_types=APIHelper.SKIP,
        program_ids=APIHelper.SKIP,
        include_inactive=APIHelper.SKIP,
        limit=APIHelper.SKIP,
        offset=APIHelper.SKIP):
        """Initialize a GetResourcesRequest instance."""
        # Initialize members of the class
        if resource_ids is not APIHelper.SKIP:
            self.resource_ids = resource_ids
        if location_ids is not APIHelper.SKIP:
            self.location_ids = location_ids
        if schedule_types is not APIHelper.SKIP:
            self.schedule_types = schedule_types
        if program_ids is not APIHelper.SKIP:
            self.program_ids = program_ids
        if include_inactive is not APIHelper.SKIP:
            self.include_inactive = include_inactive
        if limit is not APIHelper.SKIP:
            self.limit = limit
        if offset is not APIHelper.SKIP:
            self.offset = offset

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        resource_ids =\
            dictionary.get("ResourceIds")\
            if dictionary.get("ResourceIds")\
                else APIHelper.SKIP
        location_ids =\
            dictionary.get("LocationIds")\
            if dictionary.get("LocationIds")\
                else APIHelper.SKIP
        schedule_types =\
            dictionary.get("ScheduleTypes")\
            if dictionary.get("ScheduleTypes")\
                else APIHelper.SKIP
        program_ids =\
            dictionary.get("ProgramIds")\
            if dictionary.get("ProgramIds")\
                else APIHelper.SKIP
        include_inactive =\
            dictionary.get("IncludeInactive")\
            if "IncludeInactive" in dictionary.keys()\
                else APIHelper.SKIP
        limit =\
            dictionary.get("Limit")\
            if dictionary.get("Limit")\
                else APIHelper.SKIP
        offset =\
            dictionary.get("Offset")\
            if dictionary.get("Offset")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(resource_ids,
                   location_ids,
                   schedule_types,
                   program_ids,
                   include_inactive,
                   limit,
                   offset)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _resource_ids=(
            self.resource_ids
            if hasattr(self, "resource_ids")
            else None
        )
        _location_ids=(
            self.location_ids
            if hasattr(self, "location_ids")
            else None
        )
        _schedule_types=(
            self.schedule_types
            if hasattr(self, "schedule_types")
            else None
        )
        _program_ids=(
            self.program_ids
            if hasattr(self, "program_ids")
            else None
        )
        _include_inactive=(
            self.include_inactive
            if hasattr(self, "include_inactive")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"resource_ids={_resource_ids!r}, "
            f"location_ids={_location_ids!r}, "
            f"schedule_types={_schedule_types!r}, "
            f"program_ids={_program_ids!r}, "
            f"include_inactive={_include_inactive!r}, "
            f"limit={_limit!r}, "
            f"offset={_offset!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _resource_ids=(
            self.resource_ids
            if hasattr(self, "resource_ids")
            else None
        )
        _location_ids=(
            self.location_ids
            if hasattr(self, "location_ids")
            else None
        )
        _schedule_types=(
            self.schedule_types
            if hasattr(self, "schedule_types")
            else None
        )
        _program_ids=(
            self.program_ids
            if hasattr(self, "program_ids")
            else None
        )
        _include_inactive=(
            self.include_inactive
            if hasattr(self, "include_inactive")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"resource_ids={_resource_ids!s}, "
            f"location_ids={_location_ids!s}, "
            f"schedule_types={_schedule_types!s}, "
            f"program_ids={_program_ids!s}, "
            f"include_inactive={_include_inactive!s}, "
            f"limit={_limit!s}, "
            f"offset={_offset!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetEnrollmentsRequest(object):
    """Implementation of the 'GetEnrollmentsRequest' model.

    Attributes:
        class_schedule_ids (List[int]): A list of the requested class schedule IDs.
            If omitted, all class schedule IDs return.
        end_date (datetime): The end of the date range. The response returns any
            active enrollments that occur on or before this day.<br />  Default:
            **StartDate**
        location_ids (List[int]): List of the IDs for the requested locations. If
            omitted, all location IDs return.
        program_ids (List[int]): List of the IDs for the requested programs. If
            omitted, all program IDs return.
        session_type_ids (List[int]): List of the IDs for the requested session
            types. If omitted, all session types IDs return.
        staff_ids (List[int]): List of the IDs for the requested staff IDs. If
            omitted, all staff IDs return.
        start_date (datetime): The start of the date range. The response returns any
            active enrollments that occur on or after this day.<br />  Default:
            **today’s date**
        limit (int): Number of results to include, defaults to 100
        offset (int): Page offset, defaults to 0.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "class_schedule_ids": "ClassScheduleIds",
        "end_date": "EndDate",
        "location_ids": "LocationIds",
        "program_ids": "ProgramIds",
        "session_type_ids": "SessionTypeIds",
        "staff_ids": "StaffIds",
        "start_date": "StartDate",
        "limit": "Limit",
        "offset": "Offset",
    }

    _optionals = [
        "class_schedule_ids",
        "end_date",
        "location_ids",
        "program_ids",
        "session_type_ids",
        "staff_ids",
        "start_date",
        "limit",
        "offset",
    ]

    def __init__(
        self,
        class_schedule_ids=APIHelper.SKIP,
        end_date=APIHelper.SKIP,
        location_ids=APIHelper.SKIP,
        program_ids=APIHelper.SKIP,
        session_type_ids=APIHelper.SKIP,
        staff_ids=APIHelper.SKIP,
        start_date=APIHelper.SKIP,
        limit=APIHelper.SKIP,
        offset=APIHelper.SKIP):
        """Initialize a GetEnrollmentsRequest instance."""
        # Initialize members of the class
        if class_schedule_ids is not APIHelper.SKIP:
            self.class_schedule_ids = class_schedule_ids
        if end_date is not APIHelper.SKIP:
            self.end_date =\
                 APIHelper.apply_datetime_converter(
                end_date, APIHelper.RFC3339DateTime)\
                 if end_date else None
        if location_ids is not APIHelper.SKIP:
            self.location_ids = location_ids
        if program_ids is not APIHelper.SKIP:
            self.program_ids = program_ids
        if session_type_ids is not APIHelper.SKIP:
            self.session_type_ids = session_type_ids
        if staff_ids is not APIHelper.SKIP:
            self.staff_ids = staff_ids
        if start_date is not APIHelper.SKIP:
            self.start_date =\
                 APIHelper.apply_datetime_converter(
                start_date, APIHelper.RFC3339DateTime)\
                 if start_date else None
        if limit is not APIHelper.SKIP:
            self.limit = limit
        if offset is not APIHelper.SKIP:
            self.offset = offset

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        class_schedule_ids =\
            dictionary.get("ClassScheduleIds")\
            if dictionary.get("ClassScheduleIds")\
                else APIHelper.SKIP
        end_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndDate")).datetime\
            if dictionary.get("EndDate") else APIHelper.SKIP
        location_ids =\
            dictionary.get("LocationIds")\
            if dictionary.get("LocationIds")\
                else APIHelper.SKIP
        program_ids =\
            dictionary.get("ProgramIds")\
            if dictionary.get("ProgramIds")\
                else APIHelper.SKIP
        session_type_ids =\
            dictionary.get("SessionTypeIds")\
            if dictionary.get("SessionTypeIds")\
                else APIHelper.SKIP
        staff_ids =\
            dictionary.get("StaffIds")\
            if dictionary.get("StaffIds")\
                else APIHelper.SKIP
        start_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartDate")).datetime\
            if dictionary.get("StartDate") else APIHelper.SKIP
        limit =\
            dictionary.get("Limit")\
            if dictionary.get("Limit")\
                else APIHelper.SKIP
        offset =\
            dictionary.get("Offset")\
            if dictionary.get("Offset")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(class_schedule_ids,
                   end_date,
                   location_ids,
                   program_ids,
                   session_type_ids,
                   staff_ids,
                   start_date,
                   limit,
                   offset)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _class_schedule_ids=(
            self.class_schedule_ids
            if hasattr(self, "class_schedule_ids")
            else None
        )
        _end_date=(
            self.end_date
            if hasattr(self, "end_date")
            else None
        )
        _location_ids=(
            self.location_ids
            if hasattr(self, "location_ids")
            else None
        )
        _program_ids=(
            self.program_ids
            if hasattr(self, "program_ids")
            else None
        )
        _session_type_ids=(
            self.session_type_ids
            if hasattr(self, "session_type_ids")
            else None
        )
        _staff_ids=(
            self.staff_ids
            if hasattr(self, "staff_ids")
            else None
        )
        _start_date=(
            self.start_date
            if hasattr(self, "start_date")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"class_schedule_ids={_class_schedule_ids!r}, "
            f"end_date={_end_date!r}, "
            f"location_ids={_location_ids!r}, "
            f"program_ids={_program_ids!r}, "
            f"session_type_ids={_session_type_ids!r}, "
            f"staff_ids={_staff_ids!r}, "
            f"start_date={_start_date!r}, "
            f"limit={_limit!r}, "
            f"offset={_offset!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _class_schedule_ids=(
            self.class_schedule_ids
            if hasattr(self, "class_schedule_ids")
            else None
        )
        _end_date=(
            self.end_date
            if hasattr(self, "end_date")
            else None
        )
        _location_ids=(
            self.location_ids
            if hasattr(self, "location_ids")
            else None
        )
        _program_ids=(
            self.program_ids
            if hasattr(self, "program_ids")
            else None
        )
        _session_type_ids=(
            self.session_type_ids
            if hasattr(self, "session_type_ids")
            else None
        )
        _staff_ids=(
            self.staff_ids
            if hasattr(self, "staff_ids")
            else None
        )
        _start_date=(
            self.start_date
            if hasattr(self, "start_date")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"class_schedule_ids={_class_schedule_ids!s}, "
            f"end_date={_end_date!s}, "
            f"location_ids={_location_ids!s}, "
            f"program_ids={_program_ids!s}, "
            f"session_type_ids={_session_type_ids!s}, "
            f"staff_ids={_staff_ids!s}, "
            f"start_date={_start_date!s}, "
            f"limit={_limit!s}, "
            f"offset={_offset!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: D410, E501, E101, D206
from apimatic_core.authentication.multiple.single_auth import (
    Single,
)
from apimatic_core.request_builder import RequestBuilder
from apimatic_core.response_handler import ResponseHandler
from apimatic_core.types.parameter import Parameter

from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.configuration import (
    Server,
)
from mindbodypublicapi.controllers.base_controller import (
    BaseController,
)
from mindbodypublicapi.http.http_method_enum import (
    HttpMethodEnum,
)
from mindbodypublicapi.models.create_reservation_response import (
    CreateReservationResponse,
)
from mindbodypublicapi.models.get_pick_a_spot_class_response import (
    GetPickASpotClassResponse,
)
from mindbodypublicapi.models.get_reservation_response import (
    GetReservationResponse,
)
from mindbodypublicapi.models.http_content import (
    HttpContent,
)
from mindbodypublicapi.models.update_reservation_response import (
    UpdateReservationResponse,
)


class PickASpotController(BaseController):
    """A Controller to access Endpoints in the mindbodypublicapi API."""

    def __init__(self, config):
        """Initialize PickASpotController object."""
        super(PickASpotController, self).__init__(config)

    def get_class_list(self,
                       version,
                       site_id,
                       authorization=None):
        """Perform a GET request to /public/v{version}/pickaspot/v1/class.

        This endpoint supports pagination. See Pagination object for a description.

        Args:
            version (str): version of the api.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.

        Returns:
            GetPickASpotClassResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/pickaspot/v1/class")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetPickASpotClassResponse.from_dictionary),
        ).execute()

    def get_class(self,
                  version,
                  class_id,
                  site_id,
                  authorization=None):
        """Perform a GET request to
        /public/v{version}/pickaspot/v1/class/{classId}.

        Get a class filtered by classId.

        Args:
            version (str): version of the api.
            class_id (str): The request template parameter.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.

        Returns:
            GetPickASpotClassResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/pickaspot/v1/class/{classId}")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .template_param(Parameter()
                .key("classId")
                .value(class_id)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetPickASpotClassResponse.from_dictionary),
        ).execute()

    def get_reservation(self,
                        version,
                        path_info,
                        site_id,
                        authorization=None):
        """Perform a GET request to
        /public/v{version}/pickaspot/v1/reservation/{pathInfo}.

        Retrieves reservation for Pick a Spot.

        Args:
            version (str): version of the api.
            path_info (str): The request template parameter.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.

        Returns:
            GetReservationResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/pickaspot/v1/reservation/{pathInfo}")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .template_param(Parameter()
                .key("pathInfo")
                .value(path_info)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetReservationResponse.from_dictionary),
        ).execute()

    def update_reservation(self,
                           version,
                           path_info,
                           site_id,
                           authorization=None):
        """Perform a PUT request to
        /public/v{version}/pickaspot/v1/reservation/{pathInfo}.

        A user token is required for this endpoint.
        This endpoint updates a single reservation.

        Args:
            version (str): version of the api.
            path_info (str): The request template parameter.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.

        Returns:
            UpdateReservationResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/pickaspot/v1/reservation/{pathInfo}")
            .http_method(HttpMethodEnum.PUT)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .template_param(Parameter()
                .key("pathInfo")
                .value(path_info)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(UpdateReservationResponse.from_dictionary),
        ).execute()

    def create_reservation(self,
                           version,
                           path_info,
                           site_id,
                           authorization=None):
        """Perform a POST request to
        /public/v{version}/pickaspot/v1/reservation/{pathInfo}.

        Creates a spot reservation for a given pick-a-spot class. The actual class
        visit must be created prior to calling this endpoint.
        A user token is required for this endpoint.

        Sample request:

            POST /pickaspot/v1/reservation
            {
                "SiteId": -1147483363,
                "LocationId": 1,
                "ClassId": "64b14ac8c20ae8f0afd2d409",
                "ReservationExternalId": "44724", // this is a Visit.Id and should be
        linked to a specific class visit
                "MemberExternalId": "100000136", // this is Client's UniqueId
                "SpotNumber": "5",
                "ReservationDisplayName": "ReservationDisplayName", // optional
                "ReservationType": "Member", // optional. Can be Member, Guest,
        Instructor, FamilyMember,
                "AutoConfirm": false, // optional. Default: false
                "AutoAssignSpot": false // optional. It will override the
        "SpotNumber" passed and auto assign one. Default: false
            }

        Args:
            version (str): version of the api.
            path_info (str): The request template parameter.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.

        Returns:
            CreateReservationResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/pickaspot/v1/reservation/{pathInfo}")
            .http_method(HttpMethodEnum.POST)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .template_param(Parameter()
                .key("pathInfo")
                .value(path_info)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(CreateReservationResponse.from_dictionary),
        ).execute()

    def delete_reservation(self,
                           version,
                           path_info,
                           site_id,
                           authorization=None):
        """Perform a DELETE request to
        /public/v{version}/pickaspot/v1/reservation/{pathInfo}.

        A user token is required for this endpoint.
        This endpoint deletes a single reservation.

        Args:
            version (str): version of the api.
            path_info (str): The request template parameter.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.

        Returns:
            HttpContent: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/pickaspot/v1/reservation/{pathInfo}")
            .http_method(HttpMethodEnum.DELETE)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .template_param(Parameter()
                .key("pathInfo")
                .value(path_info)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(HttpContent.from_dictionary),
        ).execute()



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.lead_channel import (
    LeadChannel,
)


class Site(object):
    """Implementation of the 'Site' model.

    Attributes:
        accepts_american_express (bool): When `true`, indicates that this site
            accepts American Express cards.<br />  When `false`, indicates that this
            site does not accept American Express credit cards.
        accepts_discover (bool): When `true`, indicates that this site accepts
            Discover cards.<br />  When `false`, indicates that this site does not
            accept Discover credit cards.
        accepts_master_card (bool): When `true`, indicates that this site accepts
            MasterCard cards.<br />  When `false`, indicates that this site does not
            accept MasterCard credit cards.
        accepts_visa (bool): When `true`, indicates that this site accepts Visa
            cards.<br />  When `false`, indicates that this site does not accept Visa
            credit cards.
        allows_dashboard_access (bool): When `true`, indicates that this site allows
            access to its dashboard.<br />  When `false`, indicates that this site
            does not allow access to its dashboard.
        contact_email (str): The site’s email address.
        description (str): A description of the site.
        id (int): The site ID.
        logo_url (str): The URL to the site’s logo.
        name (str): The name of the site.
        page_color_1 (str): A hex code for a color the business owner uses in
            marketing. This color can be used to set a theme for an integration so
            that it matches the configured color-scheme for the business.
        page_color_2 (str): The hex code for a second color, to be used in the same
            manner as `pageColor1`.
        page_color_3 (str): The hex code for a third color, to be used in the same
            manner as `pageColor1`.
        page_color_4 (str): The hex code for a fourth color, to be used in the same
            manner as `pageColor1`.
        pricing_level (str): The MINDBODY pricing level for the business. Possible
            values are:  Accelerate - The business is on MINDBODY’s Accelerate
            pricing tier.  Grow - The business is on MINDBODY’s Essential pricing
            tier.  Legacy - The business is on an older MINDBODY pricing tier that is
            no longer offered.  Listing - The business is on an older MINDBODY
            pricing tier that is no longer offered.  Pro - The business is on an
            older MINDBODY pricing tier that is no longer offered.  Solo - The
            business is on an older MINDBODY pricing tier that is no longer offered.
            Ultimate - The business is on MINDBODY’s Ultimate pricing tier.
        sms_package_enabled (bool): When `true`, indicates that the business uses SMS
            text messages to communicate with its clients.<br />  When `false`,
            indicates that the business does not use SMS text messages to communicate
            with its clients.
        tax_inclusive_prices (bool): When `true`, indicates that the total includes
            tax.<br />  When `false`, indicates that the total does not include tax.
        currency_iso_code (str): The currency ISO code for the site.
        country_code (str): The country code for the site.
        time_zone (str): The time zone the site is located in.
        accepts_direct_debit (bool): When `true`, indicates that direct debit can be
            used by clients at this site.<br />  When `false`, indicates that direct
            debit can not by used by clients at this site.
        lead_channels (List[LeadChannel]): The list of lead channels available for a
            subscriber/studio.
        per_staff_pricing (bool): When `true`, indicates that per-staff pricing is
            enabled at this site.<br />  When `false`, indicates that per-staff
            pricing is not enabled at this site.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "accepts_american_express": "AcceptsAmericanExpress",
        "accepts_discover": "AcceptsDiscover",
        "accepts_master_card": "AcceptsMasterCard",
        "accepts_visa": "AcceptsVisa",
        "allows_dashboard_access": "AllowsDashboardAccess",
        "contact_email": "ContactEmail",
        "description": "Description",
        "id": "Id",
        "logo_url": "LogoUrl",
        "name": "Name",
        "page_color_1": "PageColor1",
        "page_color_2": "PageColor2",
        "page_color_3": "PageColor3",
        "page_color_4": "PageColor4",
        "pricing_level": "PricingLevel",
        "sms_package_enabled": "SmsPackageEnabled",
        "tax_inclusive_prices": "TaxInclusivePrices",
        "currency_iso_code": "CurrencyIsoCode",
        "country_code": "CountryCode",
        "time_zone": "TimeZone",
        "accepts_direct_debit": "AcceptsDirectDebit",
        "lead_channels": "LeadChannels",
        "per_staff_pricing": "PerStaffPricing",
    }

    _optionals = [
        "accepts_american_express",
        "accepts_discover",
        "accepts_master_card",
        "accepts_visa",
        "allows_dashboard_access",
        "contact_email",
        "description",
        "id",
        "logo_url",
        "name",
        "page_color_1",
        "page_color_2",
        "page_color_3",
        "page_color_4",
        "pricing_level",
        "sms_package_enabled",
        "tax_inclusive_prices",
        "currency_iso_code",
        "country_code",
        "time_zone",
        "accepts_direct_debit",
        "lead_channels",
        "per_staff_pricing",
    ]

    def __init__(
        self,
        accepts_american_express=APIHelper.SKIP,
        accepts_discover=APIHelper.SKIP,
        accepts_master_card=APIHelper.SKIP,
        accepts_visa=APIHelper.SKIP,
        allows_dashboard_access=APIHelper.SKIP,
        contact_email=APIHelper.SKIP,
        description=APIHelper.SKIP,
        id=APIHelper.SKIP,
        logo_url=APIHelper.SKIP,
        name=APIHelper.SKIP,
        page_color_1=APIHelper.SKIP,
        page_color_2=APIHelper.SKIP,
        page_color_3=APIHelper.SKIP,
        page_color_4=APIHelper.SKIP,
        pricing_level=APIHelper.SKIP,
        sms_package_enabled=APIHelper.SKIP,
        tax_inclusive_prices=APIHelper.SKIP,
        currency_iso_code=APIHelper.SKIP,
        country_code=APIHelper.SKIP,
        time_zone=APIHelper.SKIP,
        accepts_direct_debit=APIHelper.SKIP,
        lead_channels=APIHelper.SKIP,
        per_staff_pricing=APIHelper.SKIP):
        """Initialize a Site instance."""
        # Initialize members of the class
        if accepts_american_express is not APIHelper.SKIP:
            self.accepts_american_express = accepts_american_express
        if accepts_discover is not APIHelper.SKIP:
            self.accepts_discover = accepts_discover
        if accepts_master_card is not APIHelper.SKIP:
            self.accepts_master_card = accepts_master_card
        if accepts_visa is not APIHelper.SKIP:
            self.accepts_visa = accepts_visa
        if allows_dashboard_access is not APIHelper.SKIP:
            self.allows_dashboard_access = allows_dashboard_access
        if contact_email is not APIHelper.SKIP:
            self.contact_email = contact_email
        if description is not APIHelper.SKIP:
            self.description = description
        if id is not APIHelper.SKIP:
            self.id = id
        if logo_url is not APIHelper.SKIP:
            self.logo_url = logo_url
        if name is not APIHelper.SKIP:
            self.name = name
        if page_color_1 is not APIHelper.SKIP:
            self.page_color_1 = page_color_1
        if page_color_2 is not APIHelper.SKIP:
            self.page_color_2 = page_color_2
        if page_color_3 is not APIHelper.SKIP:
            self.page_color_3 = page_color_3
        if page_color_4 is not APIHelper.SKIP:
            self.page_color_4 = page_color_4
        if pricing_level is not APIHelper.SKIP:
            self.pricing_level = pricing_level
        if sms_package_enabled is not APIHelper.SKIP:
            self.sms_package_enabled = sms_package_enabled
        if tax_inclusive_prices is not APIHelper.SKIP:
            self.tax_inclusive_prices = tax_inclusive_prices
        if currency_iso_code is not APIHelper.SKIP:
            self.currency_iso_code = currency_iso_code
        if country_code is not APIHelper.SKIP:
            self.country_code = country_code
        if time_zone is not APIHelper.SKIP:
            self.time_zone = time_zone
        if accepts_direct_debit is not APIHelper.SKIP:
            self.accepts_direct_debit = accepts_direct_debit
        if lead_channels is not APIHelper.SKIP:
            self.lead_channels = lead_channels
        if per_staff_pricing is not APIHelper.SKIP:
            self.per_staff_pricing = per_staff_pricing

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        accepts_american_express =\
            dictionary.get("AcceptsAmericanExpress")\
            if "AcceptsAmericanExpress" in dictionary.keys()\
                else APIHelper.SKIP
        accepts_discover =\
            dictionary.get("AcceptsDiscover")\
            if "AcceptsDiscover" in dictionary.keys()\
                else APIHelper.SKIP
        accepts_master_card =\
            dictionary.get("AcceptsMasterCard")\
            if "AcceptsMasterCard" in dictionary.keys()\
                else APIHelper.SKIP
        accepts_visa =\
            dictionary.get("AcceptsVisa")\
            if "AcceptsVisa" in dictionary.keys()\
                else APIHelper.SKIP
        allows_dashboard_access =\
            dictionary.get("AllowsDashboardAccess")\
            if "AllowsDashboardAccess" in dictionary.keys()\
                else APIHelper.SKIP
        contact_email =\
            dictionary.get("ContactEmail")\
            if dictionary.get("ContactEmail")\
                else APIHelper.SKIP
        description =\
            dictionary.get("Description")\
            if dictionary.get("Description")\
                else APIHelper.SKIP
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        logo_url =\
            dictionary.get("LogoUrl")\
            if dictionary.get("LogoUrl")\
                else APIHelper.SKIP
        name =\
            dictionary.get("Name")\
            if dictionary.get("Name")\
                else APIHelper.SKIP
        page_color_1 =\
            dictionary.get("PageColor1")\
            if dictionary.get("PageColor1")\
                else APIHelper.SKIP
        page_color_2 =\
            dictionary.get("PageColor2")\
            if dictionary.get("PageColor2")\
                else APIHelper.SKIP
        page_color_3 =\
            dictionary.get("PageColor3")\
            if dictionary.get("PageColor3")\
                else APIHelper.SKIP
        page_color_4 =\
            dictionary.get("PageColor4")\
            if dictionary.get("PageColor4")\
                else APIHelper.SKIP
        pricing_level =\
            dictionary.get("PricingLevel")\
            if dictionary.get("PricingLevel")\
                else APIHelper.SKIP
        sms_package_enabled =\
            dictionary.get("SmsPackageEnabled")\
            if "SmsPackageEnabled" in dictionary.keys()\
                else APIHelper.SKIP
        tax_inclusive_prices =\
            dictionary.get("TaxInclusivePrices")\
            if "TaxInclusivePrices" in dictionary.keys()\
                else APIHelper.SKIP
        currency_iso_code =\
            dictionary.get("CurrencyIsoCode")\
            if dictionary.get("CurrencyIsoCode")\
                else APIHelper.SKIP
        country_code =\
            dictionary.get("CountryCode")\
            if dictionary.get("CountryCode")\
                else APIHelper.SKIP
        time_zone =\
            dictionary.get("TimeZone")\
            if dictionary.get("TimeZone")\
                else APIHelper.SKIP
        accepts_direct_debit =\
            dictionary.get("AcceptsDirectDebit")\
            if "AcceptsDirectDebit" in dictionary.keys()\
                else APIHelper.SKIP
        lead_channels = None
        if dictionary.get("LeadChannels") is not None:
            lead_channels = [
                LeadChannel.from_dictionary(x)
                    for x in dictionary.get("LeadChannels")
            ]
        else:
            lead_channels = APIHelper.SKIP
        per_staff_pricing =\
            dictionary.get("PerStaffPricing")\
            if "PerStaffPricing" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(accepts_american_express,
                   accepts_discover,
                   accepts_master_card,
                   accepts_visa,
                   allows_dashboard_access,
                   contact_email,
                   description,
                   id,
                   logo_url,
                   name,
                   page_color_1,
                   page_color_2,
                   page_color_3,
                   page_color_4,
                   pricing_level,
                   sms_package_enabled,
                   tax_inclusive_prices,
                   currency_iso_code,
                   country_code,
                   time_zone,
                   accepts_direct_debit,
                   lead_channels,
                   per_staff_pricing)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _accepts_american_express=(
            self.accepts_american_express
            if hasattr(self, "accepts_american_express")
            else None
        )
        _accepts_discover=(
            self.accepts_discover
            if hasattr(self, "accepts_discover")
            else None
        )
        _accepts_master_card=(
            self.accepts_master_card
            if hasattr(self, "accepts_master_card")
            else None
        )
        _accepts_visa=(
            self.accepts_visa
            if hasattr(self, "accepts_visa")
            else None
        )
        _allows_dashboard_access=(
            self.allows_dashboard_access
            if hasattr(self, "allows_dashboard_access")
            else None
        )
        _contact_email=(
            self.contact_email
            if hasattr(self, "contact_email")
            else None
        )
        _description=(
            self.description
            if hasattr(self, "description")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _logo_url=(
            self.logo_url
            if hasattr(self, "logo_url")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _page_color_1=(
            self.page_color_1
            if hasattr(self, "page_color_1")
            else None
        )
        _page_color_2=(
            self.page_color_2
            if hasattr(self, "page_color_2")
            else None
        )
        _page_color_3=(
            self.page_color_3
            if hasattr(self, "page_color_3")
            else None
        )
        _page_color_4=(
            self.page_color_4
            if hasattr(self, "page_color_4")
            else None
        )
        _pricing_level=(
            self.pricing_level
            if hasattr(self, "pricing_level")
            else None
        )
        _sms_package_enabled=(
            self.sms_package_enabled
            if hasattr(self, "sms_package_enabled")
            else None
        )
        _tax_inclusive_prices=(
            self.tax_inclusive_prices
            if hasattr(self, "tax_inclusive_prices")
            else None
        )
        _currency_iso_code=(
            self.currency_iso_code
            if hasattr(self, "currency_iso_code")
            else None
        )
        _country_code=(
            self.country_code
            if hasattr(self, "country_code")
            else None
        )
        _time_zone=(
            self.time_zone
            if hasattr(self, "time_zone")
            else None
        )
        _accepts_direct_debit=(
            self.accepts_direct_debit
            if hasattr(self, "accepts_direct_debit")
            else None
        )
        _lead_channels=(
            self.lead_channels
            if hasattr(self, "lead_channels")
            else None
        )
        _per_staff_pricing=(
            self.per_staff_pricing
            if hasattr(self, "per_staff_pricing")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"accepts_american_express={_accepts_american_express!r}, "
            f"accepts_discover={_accepts_discover!r}, "
            f"accepts_master_card={_accepts_master_card!r}, "
            f"accepts_visa={_accepts_visa!r}, "
            f"allows_dashboard_access={_allows_dashboard_access!r}, "
            f"contact_email={_contact_email!r}, "
            f"description={_description!r}, "
            f"id={_id!r}, "
            f"logo_url={_logo_url!r}, "
            f"name={_name!r}, "
            f"page_color_1={_page_color_1!r}, "
            f"page_color_2={_page_color_2!r}, "
            f"page_color_3={_page_color_3!r}, "
            f"page_color_4={_page_color_4!r}, "
            f"pricing_level={_pricing_level!r}, "
            f"sms_package_enabled={_sms_package_enabled!r}, "
            f"tax_inclusive_prices={_tax_inclusive_prices!r}, "
            f"currency_iso_code={_currency_iso_code!r}, "
            f"country_code={_country_code!r}, "
            f"time_zone={_time_zone!r}, "
            f"accepts_direct_debit={_accepts_direct_debit!r}, "
            f"lead_channels={_lead_channels!r}, "
            f"per_staff_pricing={_per_staff_pricing!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _accepts_american_express=(
            self.accepts_american_express
            if hasattr(self, "accepts_american_express")
            else None
        )
        _accepts_discover=(
            self.accepts_discover
            if hasattr(self, "accepts_discover")
            else None
        )
        _accepts_master_card=(
            self.accepts_master_card
            if hasattr(self, "accepts_master_card")
            else None
        )
        _accepts_visa=(
            self.accepts_visa
            if hasattr(self, "accepts_visa")
            else None
        )
        _allows_dashboard_access=(
            self.allows_dashboard_access
            if hasattr(self, "allows_dashboard_access")
            else None
        )
        _contact_email=(
            self.contact_email
            if hasattr(self, "contact_email")
            else None
        )
        _description=(
            self.description
            if hasattr(self, "description")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _logo_url=(
            self.logo_url
            if hasattr(self, "logo_url")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _page_color_1=(
            self.page_color_1
            if hasattr(self, "page_color_1")
            else None
        )
        _page_color_2=(
            self.page_color_2
            if hasattr(self, "page_color_2")
            else None
        )
        _page_color_3=(
            self.page_color_3
            if hasattr(self, "page_color_3")
            else None
        )
        _page_color_4=(
            self.page_color_4
            if hasattr(self, "page_color_4")
            else None
        )
        _pricing_level=(
            self.pricing_level
            if hasattr(self, "pricing_level")
            else None
        )
        _sms_package_enabled=(
            self.sms_package_enabled
            if hasattr(self, "sms_package_enabled")
            else None
        )
        _tax_inclusive_prices=(
            self.tax_inclusive_prices
            if hasattr(self, "tax_inclusive_prices")
            else None
        )
        _currency_iso_code=(
            self.currency_iso_code
            if hasattr(self, "currency_iso_code")
            else None
        )
        _country_code=(
            self.country_code
            if hasattr(self, "country_code")
            else None
        )
        _time_zone=(
            self.time_zone
            if hasattr(self, "time_zone")
            else None
        )
        _accepts_direct_debit=(
            self.accepts_direct_debit
            if hasattr(self, "accepts_direct_debit")
            else None
        )
        _lead_channels=(
            self.lead_channels
            if hasattr(self, "lead_channels")
            else None
        )
        _per_staff_pricing=(
            self.per_staff_pricing
            if hasattr(self, "per_staff_pricing")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"accepts_american_express={_accepts_american_express!s}, "
            f"accepts_discover={_accepts_discover!s}, "
            f"accepts_master_card={_accepts_master_card!s}, "
            f"accepts_visa={_accepts_visa!s}, "
            f"allows_dashboard_access={_allows_dashboard_access!s}, "
            f"contact_email={_contact_email!s}, "
            f"description={_description!s}, "
            f"id={_id!s}, "
            f"logo_url={_logo_url!s}, "
            f"name={_name!s}, "
            f"page_color_1={_page_color_1!s}, "
            f"page_color_2={_page_color_2!s}, "
            f"page_color_3={_page_color_3!s}, "
            f"page_color_4={_page_color_4!s}, "
            f"pricing_level={_pricing_level!s}, "
            f"sms_package_enabled={_sms_package_enabled!s}, "
            f"tax_inclusive_prices={_tax_inclusive_prices!s}, "
            f"currency_iso_code={_currency_iso_code!s}, "
            f"country_code={_country_code!s}, "
            f"time_zone={_time_zone!s}, "
            f"accepts_direct_debit={_accepts_direct_debit!s}, "
            f"lead_channels={_lead_channels!s}, "
            f"per_staff_pricing={_per_staff_pricing!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetActiveSessionTimesRequest(object):
    """Implementation of the 'GetActiveSessionTimesRequest' model.

    Attributes:
        schedule_type (ScheduleType1Enum): Filters on the provided the schedule type.
            Either `SessionTypeIds` or `ScheduleType` must be provided.
        session_type_ids (List[int]): Filters on the provided session type IDs.
            Either `SessionTypeIds` or `ScheduleType` must be provided.
        start_time (datetime): Filters results to times that start on or after this
            time on the current date. Any date provided is ignored.  <br />Default:
            **00:00:00**
        end_time (datetime): Filters results to times that end on or before this time
            on the current date. Any date provided is ignored..  <br />Default:
            **23:59:59**
        limit (int): Number of results to include, defaults to 100
        offset (int): Page offset, defaults to 0.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "schedule_type": "ScheduleType",
        "session_type_ids": "SessionTypeIds",
        "start_time": "StartTime",
        "end_time": "EndTime",
        "limit": "Limit",
        "offset": "Offset",
    }

    _optionals = [
        "schedule_type",
        "session_type_ids",
        "start_time",
        "end_time",
        "limit",
        "offset",
    ]

    def __init__(
        self,
        schedule_type=APIHelper.SKIP,
        session_type_ids=APIHelper.SKIP,
        start_time=APIHelper.SKIP,
        end_time=APIHelper.SKIP,
        limit=APIHelper.SKIP,
        offset=APIHelper.SKIP):
        """Initialize a GetActiveSessionTimesRequest instance."""
        # Initialize members of the class
        if schedule_type is not APIHelper.SKIP:
            self.schedule_type = schedule_type
        if session_type_ids is not APIHelper.SKIP:
            self.session_type_ids = session_type_ids
        if start_time is not APIHelper.SKIP:
            self.start_time =\
                 APIHelper.apply_datetime_converter(
                start_time, APIHelper.RFC3339DateTime)\
                 if start_time else None
        if end_time is not APIHelper.SKIP:
            self.end_time =\
                 APIHelper.apply_datetime_converter(
                end_time, APIHelper.RFC3339DateTime)\
                 if end_time else None
        if limit is not APIHelper.SKIP:
            self.limit = limit
        if offset is not APIHelper.SKIP:
            self.offset = offset

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        schedule_type =\
            dictionary.get("ScheduleType")\
            if dictionary.get("ScheduleType")\
                else APIHelper.SKIP
        session_type_ids =\
            dictionary.get("SessionTypeIds")\
            if dictionary.get("SessionTypeIds")\
                else APIHelper.SKIP
        start_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartTime")).datetime\
            if dictionary.get("StartTime") else APIHelper.SKIP
        end_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndTime")).datetime\
            if dictionary.get("EndTime") else APIHelper.SKIP
        limit =\
            dictionary.get("Limit")\
            if dictionary.get("Limit")\
                else APIHelper.SKIP
        offset =\
            dictionary.get("Offset")\
            if dictionary.get("Offset")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(schedule_type,
                   session_type_ids,
                   start_time,
                   end_time,
                   limit,
                   offset)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _schedule_type=(
            self.schedule_type
            if hasattr(self, "schedule_type")
            else None
        )
        _session_type_ids=(
            self.session_type_ids
            if hasattr(self, "session_type_ids")
            else None
        )
        _start_time=(
            self.start_time
            if hasattr(self, "start_time")
            else None
        )
        _end_time=(
            self.end_time
            if hasattr(self, "end_time")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"schedule_type={_schedule_type!r}, "
            f"session_type_ids={_session_type_ids!r}, "
            f"start_time={_start_time!r}, "
            f"end_time={_end_time!r}, "
            f"limit={_limit!r}, "
            f"offset={_offset!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _schedule_type=(
            self.schedule_type
            if hasattr(self, "schedule_type")
            else None
        )
        _session_type_ids=(
            self.session_type_ids
            if hasattr(self, "session_type_ids")
            else None
        )
        _start_time=(
            self.start_time
            if hasattr(self, "start_time")
            else None
        )
        _end_time=(
            self.end_time
            if hasattr(self, "end_time")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"schedule_type={_schedule_type!s}, "
            f"session_type_ids={_session_type_ids!s}, "
            f"start_time={_start_time!s}, "
            f"end_time={_end_time!s}, "
            f"limit={_limit!s}, "
            f"offset={_offset!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetSalesRequest(object):
    """Implementation of the 'GetSalesRequest' model.

    Attributes:
        sale_id (int): The sale ID associated with the particular item. It Filters
            results to the requested sale ID.
        start_sale_date_time (datetime): Filters results to sales that happened after
            this date and time.
        end_sale_date_time (datetime): Filters results to sales that happened before
            this date and time.
        payment_method_id (int): Filters results to sales paid for by the given
            payment method ID which indicates payment method(s) (i.e. cash, VISA,
            AMEX, Check, etc.).
        limit (int): Number of results to include, defaults to 100
        offset (int): Page offset, defaults to 0.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "sale_id": "SaleId",
        "start_sale_date_time": "StartSaleDateTime",
        "end_sale_date_time": "EndSaleDateTime",
        "payment_method_id": "PaymentMethodId",
        "limit": "Limit",
        "offset": "Offset",
    }

    _optionals = [
        "sale_id",
        "start_sale_date_time",
        "end_sale_date_time",
        "payment_method_id",
        "limit",
        "offset",
    ]

    def __init__(
        self,
        sale_id=APIHelper.SKIP,
        start_sale_date_time=APIHelper.SKIP,
        end_sale_date_time=APIHelper.SKIP,
        payment_method_id=APIHelper.SKIP,
        limit=APIHelper.SKIP,
        offset=APIHelper.SKIP):
        """Initialize a GetSalesRequest instance."""
        # Initialize members of the class
        if sale_id is not APIHelper.SKIP:
            self.sale_id = sale_id
        if start_sale_date_time is not APIHelper.SKIP:
            self.start_sale_date_time =\
                 APIHelper.apply_datetime_converter(
                start_sale_date_time, APIHelper.RFC3339DateTime)\
                 if start_sale_date_time else None
        if end_sale_date_time is not APIHelper.SKIP:
            self.end_sale_date_time =\
                 APIHelper.apply_datetime_converter(
                end_sale_date_time, APIHelper.RFC3339DateTime)\
                 if end_sale_date_time else None
        if payment_method_id is not APIHelper.SKIP:
            self.payment_method_id = payment_method_id
        if limit is not APIHelper.SKIP:
            self.limit = limit
        if offset is not APIHelper.SKIP:
            self.offset = offset

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        sale_id =\
            dictionary.get("SaleId")\
            if dictionary.get("SaleId")\
                else APIHelper.SKIP
        start_sale_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartSaleDateTime")).datetime\
            if dictionary.get("StartSaleDateTime") else APIHelper.SKIP
        end_sale_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndSaleDateTime")).datetime\
            if dictionary.get("EndSaleDateTime") else APIHelper.SKIP
        payment_method_id =\
            dictionary.get("PaymentMethodId")\
            if dictionary.get("PaymentMethodId")\
                else APIHelper.SKIP
        limit =\
            dictionary.get("Limit")\
            if dictionary.get("Limit")\
                else APIHelper.SKIP
        offset =\
            dictionary.get("Offset")\
            if dictionary.get("Offset")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(sale_id,
                   start_sale_date_time,
                   end_sale_date_time,
                   payment_method_id,
                   limit,
                   offset)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _sale_id=(
            self.sale_id
            if hasattr(self, "sale_id")
            else None
        )
        _start_sale_date_time=(
            self.start_sale_date_time
            if hasattr(self, "start_sale_date_time")
            else None
        )
        _end_sale_date_time=(
            self.end_sale_date_time
            if hasattr(self, "end_sale_date_time")
            else None
        )
        _payment_method_id=(
            self.payment_method_id
            if hasattr(self, "payment_method_id")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"sale_id={_sale_id!r}, "
            f"start_sale_date_time={_start_sale_date_time!r}, "
            f"end_sale_date_time={_end_sale_date_time!r}, "
            f"payment_method_id={_payment_method_id!r}, "
            f"limit={_limit!r}, "
            f"offset={_offset!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _sale_id=(
            self.sale_id
            if hasattr(self, "sale_id")
            else None
        )
        _start_sale_date_time=(
            self.start_sale_date_time
            if hasattr(self, "start_sale_date_time")
            else None
        )
        _end_sale_date_time=(
            self.end_sale_date_time
            if hasattr(self, "end_sale_date_time")
            else None
        )
        _payment_method_id=(
            self.payment_method_id
            if hasattr(self, "payment_method_id")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"sale_id={_sale_id!s}, "
            f"start_sale_date_time={_start_sale_date_time!s}, "
            f"end_sale_date_time={_end_sale_date_time!s}, "
            f"payment_method_id={_payment_method_id!s}, "
            f"limit={_limit!s}, "
            f"offset={_offset!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetAvailableDatesRequest(object):
    """Implementation of the 'GetAvailableDatesRequest' model.

    Attributes:
        session_type_id (int): required requested session type ID.
        location_id (int): optional requested location ID.
        staff_id (int): optional requested staff ID.
        start_date (datetime): The start date of the requested date range. If
            omitted, the default is used.  <br />Default: **today’s date**
        end_date (datetime): The end date of the requested date range.   <br
            />Default: **StartDate**

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "session_type_id": "SessionTypeId",
        "location_id": "LocationId",
        "staff_id": "StaffId",
        "start_date": "StartDate",
        "end_date": "EndDate",
    }

    _optionals = [
        "location_id",
        "staff_id",
        "start_date",
        "end_date",
    ]

    def __init__(
        self,
        session_type_id=None,
        location_id=APIHelper.SKIP,
        staff_id=APIHelper.SKIP,
        start_date=APIHelper.SKIP,
        end_date=APIHelper.SKIP):
        """Initialize a GetAvailableDatesRequest instance."""
        # Initialize members of the class
        self.session_type_id = session_type_id
        if location_id is not APIHelper.SKIP:
            self.location_id = location_id
        if staff_id is not APIHelper.SKIP:
            self.staff_id = staff_id
        if start_date is not APIHelper.SKIP:
            self.start_date =\
                 APIHelper.apply_datetime_converter(
                start_date, APIHelper.RFC3339DateTime)\
                 if start_date else None
        if end_date is not APIHelper.SKIP:
            self.end_date =\
                 APIHelper.apply_datetime_converter(
                end_date, APIHelper.RFC3339DateTime)\
                 if end_date else None

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        session_type_id =\
            dictionary.get("SessionTypeId")\
            if dictionary.get("SessionTypeId")\
                else None
        location_id =\
            dictionary.get("LocationId")\
            if dictionary.get("LocationId")\
                else APIHelper.SKIP
        staff_id =\
            dictionary.get("StaffId")\
            if dictionary.get("StaffId")\
                else APIHelper.SKIP
        start_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartDate")).datetime\
            if dictionary.get("StartDate") else APIHelper.SKIP
        end_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndDate")).datetime\
            if dictionary.get("EndDate") else APIHelper.SKIP

        # Return an object of this model
        return cls(session_type_id,
                   location_id,
                   staff_id,
                   start_date,
                   end_date)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _session_type_id=self.session_type_id
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _start_date=(
            self.start_date
            if hasattr(self, "start_date")
            else None
        )
        _end_date=(
            self.end_date
            if hasattr(self, "end_date")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"session_type_id={_session_type_id!r}, "
            f"location_id={_location_id!r}, "
            f"staff_id={_staff_id!r}, "
            f"start_date={_start_date!r}, "
            f"end_date={_end_date!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _session_type_id=self.session_type_id
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _start_date=(
            self.start_date
            if hasattr(self, "start_date")
            else None
        )
        _end_date=(
            self.end_date
            if hasattr(self, "end_date")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"session_type_id={_session_type_id!s}, "
            f"location_id={_location_id!s}, "
            f"staff_id={_staff_id!s}, "
            f"start_date={_start_date!s}, "
            f"end_date={_end_date!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
class UpdateStaffPermissionsRequest(object):
    """Implementation of the 'UpdateStaffPermissionsRequest' model.

    Attributes:
        staff_id (int): The ID of the staff member whose permission you want to
            change. Staff member must have a login.
        permission_group_name (str): The name of the permission group.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "staff_id": "StaffId",
        "permission_group_name": "PermissionGroupName",
    }

    def __init__(
        self,
        staff_id=None,
        permission_group_name=None):
        """Initialize a UpdateStaffPermissionsRequest instance."""
        # Initialize members of the class
        self.staff_id = staff_id
        self.permission_group_name = permission_group_name

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        staff_id =\
            dictionary.get("StaffId")\
            if dictionary.get("StaffId")\
                else None
        permission_group_name =\
            dictionary.get("PermissionGroupName")\
            if dictionary.get("PermissionGroupName")\
                else None

        # Return an object of this model
        return cls(staff_id,
                   permission_group_name)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _staff_id=self.staff_id
        _permission_group_name=self.permission_group_name
        return (
            f"{self.__class__.__name__}("
            f"staff_id={_staff_id!r}, "
            f"permission_group_name={_permission_group_name!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _staff_id=self.staff_id
        _permission_group_name=self.permission_group_name
        return (
            f"{self.__class__.__name__}("
            f"staff_id={_staff_id!s}, "
            f"permission_group_name={_permission_group_name!s}, "
            f")"
        )
